#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class force_treatment_of_unsteady_rc(Boolean):
    """
    Enable/disable use of forced treatment of unsteady terms in Rhie-Chow flux.
    """

    fluent_name = "force-treatment-of-unsteady-rc?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enhanced_cell_relocation_method import enhanced_cell_relocation_method as enhanced_cell_relocation_method_cls
from .load_legacy_particles import load_legacy_particles as load_legacy_particles_cls
from .overset_relocation_robustness_level import overset_relocation_robustness_level as overset_relocation_robustness_level_cls
from .legacy_particle_location_method_enabled import legacy_particle_location_method_enabled as legacy_particle_location_method_enabled_cls
class particle_relocation(Group):
    """
    Main menu holding information options to control relocating particles during case file reading or remeshing/adaption.
    """

    fluent_name = "particle-relocation"

    child_names = \
        ['enhanced_cell_relocation_method', 'load_legacy_particles',
         'overset_relocation_robustness_level',
         'legacy_particle_location_method_enabled']

    enhanced_cell_relocation_method: enhanced_cell_relocation_method_cls = enhanced_cell_relocation_method_cls
    """
    enhanced_cell_relocation_method child of particle_relocation.
    """
    load_legacy_particles: load_legacy_particles_cls = load_legacy_particles_cls
    """
    load_legacy_particles child of particle_relocation.
    """
    overset_relocation_robustness_level: overset_relocation_robustness_level_cls = overset_relocation_robustness_level_cls
    """
    overset_relocation_robustness_level child of particle_relocation.
    """
    legacy_particle_location_method_enabled: legacy_particle_location_method_enabled_cls = legacy_particle_location_method_enabled_cls
    """
    legacy_particle_location_method_enabled child of particle_relocation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .selection_type import selection_type as selection_type_cls
from .settings_4 import settings as settings_cls
from .reset_1 import reset as reset_cls
class clip_box_options(Group):
    """
    'clip_box_options' child.
    """

    fluent_name = "clip-box-options"

    child_names = \
        ['selection_type', 'settings']

    selection_type: selection_type_cls = selection_type_cls
    """
    selection_type child of clip_box_options.
    """
    settings: settings_cls = settings_cls
    """
    settings child of clip_box_options.
    """
    command_names = \
        ['reset']

    reset: reset_cls = reset_cls
    """
    reset command of clip_box_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .scaled import scaled as scaled_cls
from .report_type import report_type as report_type_cls
from .average_over import average_over as average_over_cls
from .per_zone import per_zone as per_zone_cls
from .thread_names import thread_names as thread_names_cls
from .thread_ids import thread_ids as thread_ids_cls
from .old_props import old_props as old_props_cls
from .reference_frame import reference_frame as reference_frame_cls
from .force_vector import force_vector as force_vector_cls
class force_child(Group):
    """
    'child_object_type' of force.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['retain_instantaneous_values', 'scaled', 'report_type',
         'average_over', 'per_zone', 'thread_names', 'thread_ids',
         'old_props', 'reference_frame', 'force_vector']

    retain_instantaneous_values: retain_instantaneous_values_cls = retain_instantaneous_values_cls
    """
    retain_instantaneous_values child of force_child.
    """
    scaled: scaled_cls = scaled_cls
    """
    scaled child of force_child.
    """
    report_type: report_type_cls = report_type_cls
    """
    report_type child of force_child.
    """
    average_over: average_over_cls = average_over_cls
    """
    average_over child of force_child.
    """
    per_zone: per_zone_cls = per_zone_cls
    """
    per_zone child of force_child.
    """
    thread_names: thread_names_cls = thread_names_cls
    """
    thread_names child of force_child.
    """
    thread_ids: thread_ids_cls = thread_ids_cls
    """
    thread_ids child of force_child.
    """
    old_props: old_props_cls = old_props_cls
    """
    old_props child of force_child.
    """
    reference_frame: reference_frame_cls = reference_frame_cls
    """
    reference_frame child of force_child.
    """
    force_vector: force_vector_cls = force_vector_cls
    """
    force_vector child of force_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_valid_report_names import list_valid_report_names as list_valid_report_names_cls
from .define import define as define_cls
from .expr_value import expr_value as expr_value_cls
from .average_over import average_over as average_over_cls
from .old_props import old_props as old_props_cls
class expression_child(Group):
    """
    'child_object_type' of expression.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['list_valid_report_names', 'define', 'expr_value', 'average_over',
         'old_props']

    list_valid_report_names: list_valid_report_names_cls = list_valid_report_names_cls
    """
    list_valid_report_names child of expression_child.
    """
    define: define_cls = define_cls
    """
    define child of expression_child.
    """
    expr_value: expr_value_cls = expr_value_cls
    """
    expr_value child of expression_child.
    """
    average_over: average_over_cls = average_over_cls
    """
    average_over child of expression_child.
    """
    old_props: old_props_cls = old_props_cls
    """
    old_props child of expression_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_7 import option as option_cls
from .value_3 import value as value_cls
from .user_defined_function import user_defined_function as user_defined_function_cls
class boiling_point(Group):
    """
    'boiling_point' child.
    """

    fluent_name = "boiling-point"

    child_names = \
        ['option', 'value', 'user_defined_function']

    option: option_cls = option_cls
    """
    option child of boiling_point.
    """
    value: value_cls = value_cls
    """
    value child of boiling_point.
    """
    user_defined_function: user_defined_function_cls = user_defined_function_cls
    """
    user_defined_function child of boiling_point.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .lines_child import lines_child

class lines(ListObject[lines_child]):
    """
    'lines' child.
    """

    fluent_name = "lines"

    child_object_type: lines_child = lines_child
    """
    child_object_type of lines.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .front_faces_transparent import front_faces_transparent as front_faces_transparent_cls
from .projection_1 import projection as projection_cls
from .axes_1 import axes as axes_cls
from .ruler import ruler as ruler_cls
from .title import title as title_cls
from .boundary_marker import boundary_marker as boundary_marker_cls
from .anti_aliasing import anti_aliasing as anti_aliasing_cls
from .reflections import reflections as reflections_cls
from .static_shadows import static_shadows as static_shadows_cls
from .dynamic_shadows import dynamic_shadows as dynamic_shadows_cls
from .grid_plane import grid_plane as grid_plane_cls
from .headlights import headlights as headlights_cls
from .lighting import lighting as lighting_cls
from .view_name import view_name as view_name_cls
class display_states_child(Group):
    """
    'child_object_type' of display_states.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['front_faces_transparent', 'projection', 'axes', 'ruler', 'title',
         'boundary_marker', 'anti_aliasing', 'reflections', 'static_shadows',
         'dynamic_shadows', 'grid_plane', 'headlights', 'lighting',
         'view_name']

    front_faces_transparent: front_faces_transparent_cls = front_faces_transparent_cls
    """
    front_faces_transparent child of display_states_child.
    """
    projection: projection_cls = projection_cls
    """
    projection child of display_states_child.
    """
    axes: axes_cls = axes_cls
    """
    axes child of display_states_child.
    """
    ruler: ruler_cls = ruler_cls
    """
    ruler child of display_states_child.
    """
    title: title_cls = title_cls
    """
    title child of display_states_child.
    """
    boundary_marker: boundary_marker_cls = boundary_marker_cls
    """
    boundary_marker child of display_states_child.
    """
    anti_aliasing: anti_aliasing_cls = anti_aliasing_cls
    """
    anti_aliasing child of display_states_child.
    """
    reflections: reflections_cls = reflections_cls
    """
    reflections child of display_states_child.
    """
    static_shadows: static_shadows_cls = static_shadows_cls
    """
    static_shadows child of display_states_child.
    """
    dynamic_shadows: dynamic_shadows_cls = dynamic_shadows_cls
    """
    dynamic_shadows child of display_states_child.
    """
    grid_plane: grid_plane_cls = grid_plane_cls
    """
    grid_plane child of display_states_child.
    """
    headlights: headlights_cls = headlights_cls
    """
    headlights child of display_states_child.
    """
    lighting: lighting_cls = lighting_cls
    """
    lighting child of display_states_child.
    """
    view_name: view_name_cls = view_name_cls
    """
    view_name child of display_states_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .averaged_turbulent_parameters import averaged_turbulent_parameters as averaged_turbulent_parameters_cls
from .turbulent_intensity_3 import turbulent_intensity as turbulent_intensity_cls
from .viscosity_ratio import viscosity_ratio as viscosity_ratio_cls
class turbulent_setting(Group):
    """
    Enter the turbulent settings menu.
    """

    fluent_name = "turbulent-setting"

    child_names = \
        ['averaged_turbulent_parameters', 'turbulent_intensity',
         'viscosity_ratio']

    averaged_turbulent_parameters: averaged_turbulent_parameters_cls = averaged_turbulent_parameters_cls
    """
    averaged_turbulent_parameters child of turbulent_setting.
    """
    turbulent_intensity: turbulent_intensity_cls = turbulent_intensity_cls
    """
    turbulent_intensity child of turbulent_setting.
    """
    viscosity_ratio: viscosity_ratio_cls = viscosity_ratio_cls
    """
    viscosity_ratio child of turbulent_setting.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .method_3 import method as method_cls
from .samp_time_period import samp_time_period as samp_time_period_cls
from .samp_time_steps import samp_time_steps as samp_time_steps_cls
from .avg_time_period import avg_time_period as avg_time_period_cls
from .avg_time_steps import avg_time_steps as avg_time_steps_cls
class statistics_controls(Command):
    """
    Specify statistics parameters of sampling and averaging of flow and optical quantities.
    
    Parameters
    ----------
        method : int
            'method' child.
        samp_time_period : real
            'samp_time_period' child.
        samp_time_steps : int
            'samp_time_steps' child.
        avg_time_period : real
            'avg_time_period' child.
        avg_time_steps : int
            'avg_time_steps' child.
    
    """

    fluent_name = "statistics-controls"

    argument_names = \
        ['method', 'samp_time_period', 'samp_time_steps', 'avg_time_period',
         'avg_time_steps']

    method: method_cls = method_cls
    """
    method argument of statistics_controls.
    """
    samp_time_period: samp_time_period_cls = samp_time_period_cls
    """
    samp_time_period argument of statistics_controls.
    """
    samp_time_steps: samp_time_steps_cls = samp_time_steps_cls
    """
    samp_time_steps argument of statistics_controls.
    """
    avg_time_period: avg_time_period_cls = avg_time_period_cls
    """
    avg_time_period argument of statistics_controls.
    """
    avg_time_steps: avg_time_steps_cls = avg_time_steps_cls
    """
    avg_time_steps argument of statistics_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .ap_face_zone import ap_face_zone as ap_face_zone_cls
from .beam_length import beam_length as beam_length_cls
from .ray_points_count import ray_points_count as ray_points_count_cls
from .beam_vector import beam_vector as beam_vector_cls
class beams_child(Group):
    """
    'child_object_type' of beams.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['ap_face_zone', 'beam_length', 'ray_points_count', 'beam_vector']

    ap_face_zone: ap_face_zone_cls = ap_face_zone_cls
    """
    ap_face_zone child of beams_child.
    """
    beam_length: beam_length_cls = beam_length_cls
    """
    beam_length child of beams_child.
    """
    ray_points_count: ray_points_count_cls = ray_points_count_cls
    """
    ray_points_count child of beams_child.
    """
    beam_vector: beam_vector_cls = beam_vector_cls
    """
    beam_vector child of beams_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .radiation_bc import radiation_bc as radiation_bc_cls
from .radial_direction import radial_direction as radial_direction_cls
from .theta_width_of_beam import theta_width_of_beam as theta_width_of_beam_cls
from .phi_width_of_beam import phi_width_of_beam as phi_width_of_beam_cls
from .direct_irradiation import direct_irradiation as direct_irradiation_cls
from .diffuse_irradiation import diffuse_irradiation as diffuse_irradiation_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .use_beeam_direction_from_solar_load_model_settings import use_beeam_direction_from_solar_load_model_settings as use_beeam_direction_from_solar_load_model_settings_cls
from .use_irradiation_from_solar_soad_model_settings import use_irradiation_from_solar_soad_model_settings as use_irradiation_from_solar_soad_model_settings_cls
from .external_black_body_temperature_method import external_black_body_temperature_method as external_black_body_temperature_method_cls
from .black_body_temperature import black_body_temperature as black_body_temperature_cls
from .internal_emissivity import internal_emissivity as internal_emissivity_cls
from .participates_in_solar_ray_tracing import participates_in_solar_ray_tracing as participates_in_solar_ray_tracing_cls
from .solar_transmissivity_factor import solar_transmissivity_factor as solar_transmissivity_factor_cls
from .participates_in_view_factor_calculation_1 import participates_in_view_factor_calculation as participates_in_view_factor_calculation_cls
class radiation(Group):
    """
    Help not available.
    """

    fluent_name = "radiation"

    child_names = \
        ['radiation_bc', 'radial_direction', 'theta_width_of_beam',
         'phi_width_of_beam', 'direct_irradiation', 'diffuse_irradiation',
         'parallel_collimated_beam',
         'use_beeam_direction_from_solar_load_model_settings',
         'use_irradiation_from_solar_soad_model_settings',
         'external_black_body_temperature_method', 'black_body_temperature',
         'internal_emissivity', 'participates_in_solar_ray_tracing',
         'solar_transmissivity_factor',
         'participates_in_view_factor_calculation']

    radiation_bc: radiation_bc_cls = radiation_bc_cls
    """
    radiation_bc child of radiation.
    """
    radial_direction: radial_direction_cls = radial_direction_cls
    """
    radial_direction child of radiation.
    """
    theta_width_of_beam: theta_width_of_beam_cls = theta_width_of_beam_cls
    """
    theta_width_of_beam child of radiation.
    """
    phi_width_of_beam: phi_width_of_beam_cls = phi_width_of_beam_cls
    """
    phi_width_of_beam child of radiation.
    """
    direct_irradiation: direct_irradiation_cls = direct_irradiation_cls
    """
    direct_irradiation child of radiation.
    """
    diffuse_irradiation: diffuse_irradiation_cls = diffuse_irradiation_cls
    """
    diffuse_irradiation child of radiation.
    """
    parallel_collimated_beam: parallel_collimated_beam_cls = parallel_collimated_beam_cls
    """
    parallel_collimated_beam child of radiation.
    """
    use_beeam_direction_from_solar_load_model_settings: use_beeam_direction_from_solar_load_model_settings_cls = use_beeam_direction_from_solar_load_model_settings_cls
    """
    use_beeam_direction_from_solar_load_model_settings child of radiation.
    """
    use_irradiation_from_solar_soad_model_settings: use_irradiation_from_solar_soad_model_settings_cls = use_irradiation_from_solar_soad_model_settings_cls
    """
    use_irradiation_from_solar_soad_model_settings child of radiation.
    """
    external_black_body_temperature_method: external_black_body_temperature_method_cls = external_black_body_temperature_method_cls
    """
    external_black_body_temperature_method child of radiation.
    """
    black_body_temperature: black_body_temperature_cls = black_body_temperature_cls
    """
    black_body_temperature child of radiation.
    """
    internal_emissivity: internal_emissivity_cls = internal_emissivity_cls
    """
    internal_emissivity child of radiation.
    """
    participates_in_solar_ray_tracing: participates_in_solar_ray_tracing_cls = participates_in_solar_ray_tracing_cls
    """
    participates_in_solar_ray_tracing child of radiation.
    """
    solar_transmissivity_factor: solar_transmissivity_factor_cls = solar_transmissivity_factor_cls
    """
    solar_transmissivity_factor child of radiation.
    """
    participates_in_view_factor_calculation: participates_in_view_factor_calculation_cls = participates_in_view_factor_calculation_cls
    """
    participates_in_view_factor_calculation child of radiation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class system:
    fluent_name = ...
    command_names = ...

    def print_process_statistics(self, ):
        """
        Fluent process information.
        """

    def print_system_statistics(self, ):
        """
        System information.
        """

    def print_gpgpu_statistics(self, ):
        """
        GPGPU information.
        """

    def print_time_statistics(self, ):
        """
        Time usage information.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .blade_flapping_cone import blade_flapping_cone as blade_flapping_cone_cls
from .blade_flapping_cyclic_sin import blade_flapping_cyclic_sin as blade_flapping_cyclic_sin_cls
from .blade_flapping_cyclic_cos import blade_flapping_cyclic_cos as blade_flapping_cyclic_cos_cls
class blade_flap_angles(Group):
    """
    Menu to define the rotor pitch angles.
    
     - blade-flapping-cone       : , 
     - blade-flapping-cyclic-sin : , 
     - blade-flapping-cyclic-cos : , 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "blade-flap-angles"

    child_names = \
        ['blade_flapping_cone', 'blade_flapping_cyclic_sin',
         'blade_flapping_cyclic_cos']

    blade_flapping_cone: blade_flapping_cone_cls = blade_flapping_cone_cls
    """
    blade_flapping_cone child of blade_flap_angles.
    """
    blade_flapping_cyclic_sin: blade_flapping_cyclic_sin_cls = blade_flapping_cyclic_sin_cls
    """
    blade_flapping_cyclic_sin child of blade_flap_angles.
    """
    blade_flapping_cyclic_cos: blade_flapping_cyclic_cos_cls = blade_flapping_cyclic_cos_cls
    """
    blade_flapping_cyclic_cos child of blade_flap_angles.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .methods_2 import methods as methods_cls
from .x import x as x_cls
from .y import y as y_cls
from .z import z as z_cls
from .point_vector import point_vector as point_vector_cls
from .point_normal import point_normal as point_normal_cls
from .compute_from_view_plane import compute_from_view_plane as compute_from_view_plane_cls
from .surface_aligned_normal import surface_aligned_normal as surface_aligned_normal_cls
from .p0_1 import p0 as p0_cls
from .p1 import p1 as p1_cls
from .p2 import p2 as p2_cls
from .bounded import bounded as bounded_cls
from .sample_point import sample_point as sample_point_cls
from .edges_2 import edges as edges_cls
class plane_surface_child(Group):
    """
    'child_object_type' of plane_surface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['methods', 'x', 'y', 'z', 'point_vector', 'point_normal',
         'compute_from_view_plane', 'surface_aligned_normal', 'p0', 'p1',
         'p2', 'bounded', 'sample_point', 'edges']

    methods: methods_cls = methods_cls
    """
    methods child of plane_surface_child.
    """
    x: x_cls = x_cls
    """
    x child of plane_surface_child.
    """
    y: y_cls = y_cls
    """
    y child of plane_surface_child.
    """
    z: z_cls = z_cls
    """
    z child of plane_surface_child.
    """
    point_vector: point_vector_cls = point_vector_cls
    """
    point_vector child of plane_surface_child.
    """
    point_normal: point_normal_cls = point_normal_cls
    """
    point_normal child of plane_surface_child.
    """
    compute_from_view_plane: compute_from_view_plane_cls = compute_from_view_plane_cls
    """
    compute_from_view_plane child of plane_surface_child.
    """
    surface_aligned_normal: surface_aligned_normal_cls = surface_aligned_normal_cls
    """
    surface_aligned_normal child of plane_surface_child.
    """
    p0: p0_cls = p0_cls
    """
    p0 child of plane_surface_child.
    """
    p1: p1_cls = p1_cls
    """
    p1 child of plane_surface_child.
    """
    p2: p2_cls = p2_cls
    """
    p2 child of plane_surface_child.
    """
    bounded: bounded_cls = bounded_cls
    """
    bounded child of plane_surface_child.
    """
    sample_point: sample_point_cls = sample_point_cls
    """
    sample_point child of plane_surface_child.
    """
    edges: edges_cls = edges_cls
    """
    edges child of plane_surface_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_scale_all import enable_scale_all as enable_scale_all_cls
from .disable_scale_all import disable_scale_all as disable_scale_all_cls
from .interface_name_1 import interface_name as interface_name_cls
from .scale_2 import scale as scale_cls
class enforce_flux_scaling(Command):
    """
    Enforce flux scaling ON/OFF at the turbo interfaces.
    
    Parameters
    ----------
        enable_scale_all : bool
            Scale scaling of all the interfaces...
        disable_scale_all : bool
            Disable scaling of all the interfaces...
        interface_name : str
            'interface_name' child.
        scale : bool
            Enable flux scaling at mixing plane interface.
    
    """

    fluent_name = "enforce-flux-scaling"

    argument_names = \
        ['enable_scale_all', 'disable_scale_all', 'interface_name', 'scale']

    enable_scale_all: enable_scale_all_cls = enable_scale_all_cls
    """
    enable_scale_all argument of enforce_flux_scaling.
    """
    disable_scale_all: disable_scale_all_cls = disable_scale_all_cls
    """
    disable_scale_all argument of enforce_flux_scaling.
    """
    interface_name: interface_name_cls = interface_name_cls
    """
    interface_name argument of enforce_flux_scaling.
    """
    scale: scale_cls = scale_cls
    """
    scale argument of enforce_flux_scaling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class backplate_image(String, _HasAllowedValuesMixin):
    """
    Set the backplate image. This will override the backplate color unless the image is set to 'none'.
    """

    fluent_name = "backplate-image"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class terminology(Integer):
    """
    Select Rotor Disk Orientation Terminology:
    
     - Enter 0 if using Rotor Disk Angles 
     - Enter 1 if using Rotor Disk Normal 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "terminology"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .method_2 import method as method_cls
from .time_step_interval import time_step_interval as time_step_interval_cls
from .time_interval import time_interval as time_interval_cls
from .iteration_interval import iteration_interval as iteration_interval_cls
class solve_frequency(Group):
    """
    Enter radiation solve frequency.
    """

    fluent_name = "solve-frequency"

    child_names = \
        ['method', 'time_step_interval', 'time_interval',
         'iteration_interval']

    method: method_cls = method_cls
    """
    method child of solve_frequency.
    """
    time_step_interval: time_step_interval_cls = time_step_interval_cls
    """
    time_step_interval child of solve_frequency.
    """
    time_interval: time_interval_cls = time_interval_cls
    """
    time_interval child of solve_frequency.
    """
    iteration_interval: iteration_interval_cls = iteration_interval_cls
    """
    iteration_interval child of solve_frequency.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .first_axis import first_axis as first_axis_cls
from .second_axis import second_axis as second_axis_cls
from .auto_second_axis import auto_second_axis as auto_second_axis_cls
class orientation(Group):
    """
    'orientation' child.
    """

    fluent_name = "orientation"

    child_names = \
        ['first_axis', 'second_axis', 'auto_second_axis']

    first_axis: first_axis_cls = first_axis_cls
    """
    first_axis child of orientation.
    """
    second_axis: second_axis_cls = second_axis_cls
    """
    second_axis child of orientation.
    """
    auto_second_axis: auto_second_axis_cls = auto_second_axis_cls
    """
    auto_second_axis child of orientation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .differential_viscosity_model import differential_viscosity_model as differential_viscosity_model_cls
from .swirl_dominated_flow import swirl_dominated_flow as swirl_dominated_flow_cls
class rng_options(Group):
    """
    'rng_options' child.
    """

    fluent_name = "rng-options"

    child_names = \
        ['differential_viscosity_model', 'swirl_dominated_flow']

    differential_viscosity_model: differential_viscosity_model_cls = differential_viscosity_model_cls
    """
    differential_viscosity_model child of rng_options.
    """
    swirl_dominated_flow: swirl_dominated_flow_cls = swirl_dominated_flow_cls
    """
    swirl_dominated_flow child of rng_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .initial_dod import initial_dod as initial_dod_cls
from .ref_capacity import ref_capacity as ref_capacity_cls
from .data_type import data_type as data_type_cls
from .poly_u_function import poly_u_function as poly_u_function_cls
from .poly_y_function import poly_y_function as poly_y_function_cls
from .poly_t_dependence import poly_t_dependence as poly_t_dependence_cls
from .u_table import u_table as u_table_cls
from .y_table import y_table as y_table_cls
class ntgk_model_settings(Group):
    """
    'ntgk_model_settings' child.
    """

    fluent_name = "ntgk-model-settings"

    child_names = \
        ['initial_dod', 'ref_capacity', 'data_type', 'poly_u_function',
         'poly_y_function', 'poly_t_dependence', 'u_table', 'y_table']

    initial_dod: initial_dod_cls = initial_dod_cls
    """
    initial_dod child of ntgk_model_settings.
    """
    ref_capacity: ref_capacity_cls = ref_capacity_cls
    """
    ref_capacity child of ntgk_model_settings.
    """
    data_type: data_type_cls = data_type_cls
    """
    data_type child of ntgk_model_settings.
    """
    poly_u_function: poly_u_function_cls = poly_u_function_cls
    """
    poly_u_function child of ntgk_model_settings.
    """
    poly_y_function: poly_y_function_cls = poly_y_function_cls
    """
    poly_y_function child of ntgk_model_settings.
    """
    poly_t_dependence: poly_t_dependence_cls = poly_t_dependence_cls
    """
    poly_t_dependence child of ntgk_model_settings.
    """
    u_table: u_table_cls = u_table_cls
    """
    u_table child of ntgk_model_settings.
    """
    y_table: y_table_cls = y_table_cls
    """
    y_table child of ntgk_model_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_2 import enabled as enabled_cls
from .color import color as color_cls
class constant_color(Group):
    """
    'constant_color' child.
    """

    fluent_name = "constant-color"

    child_names = \
        ['enabled', 'color']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of constant_color.
    """
    color: color_cls = color_cls
    """
    color child of constant_color.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_7 import option as option_cls
from .value_3 import value as value_cls
class degrees_of_freedom(Group):
    """
    'degrees_of_freedom' child.
    """

    fluent_name = "degrees-of-freedom"

    child_names = \
        ['option', 'value']

    option: option_cls = option_cls
    """
    option child of degrees_of_freedom.
    """
    value: value_cls = value_cls
    """
    value child of degrees_of_freedom.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class web_server:
    fluent_name = ...
    command_names = ...

    def start(self, session_name: str, port: int, port_span: int, job_service_url: str):
        """
        Start the web server.
        
        Parameters
        ----------
            session_name : str
                Name for the web server.
            port : int
                Listening port for the web server.
            port_span : int
                Number of ports to try starting from given 'port' for the web server.
            job_service_url : str
                Job service URL to register Fluent.
        
        """

    def stop(self, ):
        """
        Stop the web server.
        """

    def print_server_info(self, ):
        """
        Print the web server information.
        """

    def get_server_info(self, ):
        """
        Get the web server information.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .pattern import pattern as pattern_cls
from .weight_1 import weight as weight_cls
from .color_1 import color as color_cls
class line_in_file(Group):
    """
    Set parameters for plot lines (file).
    """

    fluent_name = "line-in-file"

    child_names = \
        ['pattern', 'weight', 'color']

    pattern: pattern_cls = pattern_cls
    """
    pattern child of line_in_file.
    """
    weight: weight_cls = weight_cls
    """
    weight child of line_in_file.
    """
    color: color_cls = color_cls
    """
    color child of line_in_file.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_5 import enable as enable_cls
from .options_3 import options as options_cls
class high_order_term_relaxation(Group):
    """
    Enter High Order Relaxation Menu.
    """

    fluent_name = "high-order-term-relaxation"

    child_names = \
        ['enable', 'options']

    enable: enable_cls = enable_cls
    """
    enable child of high_order_term_relaxation.
    """
    options: options_cls = options_cls
    """
    options child of high_order_term_relaxation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .continuous_phase import continuous_phase as continuous_phase_cls
from .enable_rough_wall_treatment import enable_rough_wall_treatment as enable_rough_wall_treatment_cls
from .volume_displacement import volume_displacement as volume_displacement_cls
class interaction(Group):
    """
    'interaction' child.
    """

    fluent_name = "interaction"

    child_names = \
        ['continuous_phase', 'enable_rough_wall_treatment',
         'volume_displacement']

    continuous_phase: continuous_phase_cls = continuous_phase_cls
    """
    continuous_phase child of interaction.
    """
    enable_rough_wall_treatment: enable_rough_wall_treatment_cls = enable_rough_wall_treatment_cls
    """
    enable_rough_wall_treatment child of interaction.
    """
    volume_displacement: volume_displacement_cls = volume_displacement_cls
    """
    volume_displacement child of interaction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class max_rendering_timeout(Integer):
    """
    Controls the maximum time [s] spent rendering before the image is captured.
    """

    fluent_name = "max-rendering-timeout"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .delete_1 import delete as delete_cls
from .list import list as list_cls
from .list_properties_1 import list_properties as list_properties_cls
from .make_a_copy import make_a_copy as make_a_copy_cls
from .cross_section_multicomponent_child import cross_section_multicomponent_child

class cross_section_multicomponent(NamedObject[cross_section_multicomponent_child], _NonCreatableNamedObjectMixin[cross_section_multicomponent_child]):
    """
    'cross_section_multicomponent' child.
    """

    fluent_name = "cross-section-multicomponent"

    command_names = \
        ['delete', 'list', 'list_properties', 'make_a_copy']

    delete: delete_cls = delete_cls
    """
    delete command of cross_section_multicomponent.
    """
    list: list_cls = list_cls
    """
    list command of cross_section_multicomponent.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of cross_section_multicomponent.
    """
    make_a_copy: make_a_copy_cls = make_a_copy_cls
    """
    make_a_copy command of cross_section_multicomponent.
    """
    child_object_type: cross_section_multicomponent_child = cross_section_multicomponent_child
    """
    child_object_type of cross_section_multicomponent.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .partition_mask import partition_mask as partition_mask_cls
from .verbosity_9 import verbosity as verbosity_cls
from .time_out import time_out as time_out_cls
from .fast_io import fast_io as fast_io_cls
class set(Group):
    """
    'set' child.
    """

    fluent_name = "set"

    child_names = \
        ['partition_mask', 'verbosity', 'time_out', 'fast_io']

    partition_mask: partition_mask_cls = partition_mask_cls
    """
    partition_mask child of set.
    """
    verbosity: verbosity_cls = verbosity_cls
    """
    verbosity child of set.
    """
    time_out: time_out_cls = time_out_cls
    """
    time_out child of set.
    """
    fast_io: fast_io_cls = fast_io_cls
    """
    fast_io child of set.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_names_2 import zone_names as zone_names_cls
from .rotation_angle import rotation_angle as rotation_angle_cls
from .origin import origin as origin_cls
from .axis import axis as axis_cls
class rotate_zone(Command):
    """
    Rotate nodal coordinates of input cell zones.
    
    Parameters
    ----------
        zone_names : typing.List[str]
            Rotate specified cell zones.
        rotation_angle : real
            'rotation_angle' child.
        origin : typing.List[real]
            'origin' child.
        axis : typing.List[real]
            'axis' child.
    
    """

    fluent_name = "rotate-zone"

    argument_names = \
        ['zone_names', 'rotation_angle', 'origin', 'axis']

    zone_names: zone_names_cls = zone_names_cls
    """
    zone_names argument of rotate_zone.
    """
    rotation_angle: rotation_angle_cls = rotation_angle_cls
    """
    rotation_angle argument of rotate_zone.
    """
    origin: origin_cls = origin_cls
    """
    origin argument of rotate_zone.
    """
    axis: axis_cls = axis_cls
    """
    axis argument of rotate_zone.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_9 import option as option_cls
from .value import value as value_cls
from .polynomial import polynomial as polynomial_cls
class species_diffusivity_child(Group):
    """
    'child_object_type' of species_diffusivity.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['option', 'value', 'polynomial']

    option: option_cls = option_cls
    """
    option child of species_diffusivity_child.
    """
    value: value_cls = value_cls
    """
    value child of species_diffusivity_child.
    """
    polynomial: polynomial_cls = polynomial_cls
    """
    polynomial child of species_diffusivity_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .convergence_acc_std_meshes import convergence_acc_std_meshes as convergence_acc_std_meshes_cls
from .enhanced_casm_formulation import enhanced_casm_formulation as enhanced_casm_formulation_cls
from .casm_cutoff_multiplier import casm_cutoff_multiplier as casm_cutoff_multiplier_cls
from .disable_casm import disable_casm as disable_casm_cls
class convergence_acceleration_for_stretched_meshes(Group):
    """
    'convergence_acceleration_for_stretched_meshes' child.
    """

    fluent_name = "convergence-acceleration-for-stretched-meshes"

    child_names = \
        ['convergence_acc_std_meshes', 'enhanced_casm_formulation',
         'casm_cutoff_multiplier']

    convergence_acc_std_meshes: convergence_acc_std_meshes_cls = convergence_acc_std_meshes_cls
    """
    convergence_acc_std_meshes child of convergence_acceleration_for_stretched_meshes.
    """
    enhanced_casm_formulation: enhanced_casm_formulation_cls = enhanced_casm_formulation_cls
    """
    enhanced_casm_formulation child of convergence_acceleration_for_stretched_meshes.
    """
    casm_cutoff_multiplier: casm_cutoff_multiplier_cls = casm_cutoff_multiplier_cls
    """
    casm_cutoff_multiplier child of convergence_acceleration_for_stretched_meshes.
    """
    command_names = \
        ['disable_casm']

    disable_casm: disable_casm_cls = disable_casm_cls
    """
    disable_casm command of convergence_acceleration_for_stretched_meshes.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class num_sub_stepping_coupling_itr(Integer):
    """
    Set the number of substeps for each coupling iterations (default = 1).
    """

    fluent_name = "num-sub-stepping-coupling-itr"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class repair_poor_elements(Command):
    """
    Report invalid and poor quality elements.
    """

    fluent_name = "repair-poor-elements"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_11 import option as option_cls
from .min_allowed import min_allowed as min_allowed_cls
from .max_allowed import max_allowed as max_allowed_cls
from .wall_zones import wall_zones as wall_zones_cls
from .phase_26 import phase as phase_cls
class yplus_ystar(Group):
    """
    'yplus_ystar' child.
    """

    fluent_name = "yplus-ystar"

    child_names = \
        ['option', 'min_allowed', 'max_allowed', 'wall_zones', 'phase']

    option: option_cls = option_cls
    """
    option child of yplus_ystar.
    """
    min_allowed: min_allowed_cls = min_allowed_cls
    """
    min_allowed child of yplus_ystar.
    """
    max_allowed: max_allowed_cls = max_allowed_cls
    """
    max_allowed child of yplus_ystar.
    """
    wall_zones: wall_zones_cls = wall_zones_cls
    """
    wall_zones child of yplus_ystar.
    """
    phase: phase_cls = phase_cls
    """
    phase child of yplus_ystar.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .omega_pe import omega_pe as omega_pe_cls
from .omega_ne import omega_ne as omega_ne_cls
from .e_elastic_pe import e_elastic_pe as e_elastic_pe_cls
from .e_elastic_sp import e_elastic_sp as e_elastic_sp_cls
from .e_elastic_ne import e_elastic_ne as e_elastic_ne_cls
from .soc_ref import soc_ref as soc_ref_cls
from .cell_type import cell_type as cell_type_cls
from .axis_vec import axis_vec as axis_vec_cls
from .normal_vec import normal_vec as normal_vec_cls
from .prism_axis_vec import prism_axis_vec as prism_axis_vec_cls
from .prism_vec2 import prism_vec2 as prism_vec2_cls
from .udf_name import udf_name as udf_name_cls
class swelling_model_parameter(Group):
    """
    'swelling_model_parameter' child.
    """

    fluent_name = "swelling-model-parameter"

    child_names = \
        ['omega_pe', 'omega_ne', 'e_elastic_pe', 'e_elastic_sp',
         'e_elastic_ne', 'soc_ref', 'cell_type', 'axis_vec', 'normal_vec',
         'prism_axis_vec', 'prism_vec2', 'udf_name']

    omega_pe: omega_pe_cls = omega_pe_cls
    """
    omega_pe child of swelling_model_parameter.
    """
    omega_ne: omega_ne_cls = omega_ne_cls
    """
    omega_ne child of swelling_model_parameter.
    """
    e_elastic_pe: e_elastic_pe_cls = e_elastic_pe_cls
    """
    e_elastic_pe child of swelling_model_parameter.
    """
    e_elastic_sp: e_elastic_sp_cls = e_elastic_sp_cls
    """
    e_elastic_sp child of swelling_model_parameter.
    """
    e_elastic_ne: e_elastic_ne_cls = e_elastic_ne_cls
    """
    e_elastic_ne child of swelling_model_parameter.
    """
    soc_ref: soc_ref_cls = soc_ref_cls
    """
    soc_ref child of swelling_model_parameter.
    """
    cell_type: cell_type_cls = cell_type_cls
    """
    cell_type child of swelling_model_parameter.
    """
    axis_vec: axis_vec_cls = axis_vec_cls
    """
    axis_vec child of swelling_model_parameter.
    """
    normal_vec: normal_vec_cls = normal_vec_cls
    """
    normal_vec child of swelling_model_parameter.
    """
    prism_axis_vec: prism_axis_vec_cls = prism_axis_vec_cls
    """
    prism_axis_vec child of swelling_model_parameter.
    """
    prism_vec2: prism_vec2_cls = prism_vec2_cls
    """
    prism_vec2 child of swelling_model_parameter.
    """
    udf_name: udf_name_cls = udf_name_cls
    """
    udf_name child of swelling_model_parameter.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .factor import factor as factor_cls
class zoom(Command):
    """
    Adjust the camera field of view.
    
    Parameters
    ----------
        factor : real
            'factor' child.
    
    """

    fluent_name = "zoom"

    argument_names = \
        ['factor']

    factor: factor_cls = factor_cls
    """
    factor argument of zoom.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class lwf_particle_inclusion_in_dpm_concentration_enabled(Boolean):
    """
    Include/exclude LWF particle mass in the calculation of DPM Concentration.
    """

    fluent_name = "lwf-particle-inclusion-in-dpm-concentration-enabled?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .min_pressure import min_pressure as min_pressure_cls
from .max_pressure import max_pressure as max_pressure_cls
from .min_temperature import min_temperature as min_temperature_cls
from .max_temperature import max_temperature as max_temperature_cls
from .min_tke import min_tke as min_tke_cls
from .min_lam_tke import min_lam_tke as min_lam_tke_cls
from .min_des_tke import min_des_tke as min_des_tke_cls
from .min_epsilon import min_epsilon as min_epsilon_cls
from .min_des_epsilon import min_des_epsilon as min_des_epsilon_cls
from .min_v2f_tke import min_v2f_tke as min_v2f_tke_cls
from .min_v2f_epsilon import min_v2f_epsilon as min_v2f_epsilon_cls
from .min_vel_var_scale import min_vel_var_scale as min_vel_var_scale_cls
from .min_elliptic_relax_func import min_elliptic_relax_func as min_elliptic_relax_func_cls
from .min_omega import min_omega as min_omega_cls
from .min_des_omega import min_des_omega as min_des_omega_cls
from .max_turb_visc_ratio import max_turb_visc_ratio as max_turb_visc_ratio_cls
from .positivity_rate import positivity_rate as positivity_rate_cls
from .min_vol_frac_for_matrix_sol import min_vol_frac_for_matrix_sol as min_vol_frac_for_matrix_sol_cls
class limits(Group):
    """
    'limits' child.
    """

    fluent_name = "limits"

    child_names = \
        ['min_pressure', 'max_pressure', 'min_temperature', 'max_temperature',
         'min_tke', 'min_lam_tke', 'min_des_tke', 'min_epsilon',
         'min_des_epsilon', 'min_v2f_tke', 'min_v2f_epsilon',
         'min_vel_var_scale', 'min_elliptic_relax_func', 'min_omega',
         'min_des_omega', 'max_turb_visc_ratio', 'positivity_rate',
         'min_vol_frac_for_matrix_sol']

    min_pressure: min_pressure_cls = min_pressure_cls
    """
    min_pressure child of limits.
    """
    max_pressure: max_pressure_cls = max_pressure_cls
    """
    max_pressure child of limits.
    """
    min_temperature: min_temperature_cls = min_temperature_cls
    """
    min_temperature child of limits.
    """
    max_temperature: max_temperature_cls = max_temperature_cls
    """
    max_temperature child of limits.
    """
    min_tke: min_tke_cls = min_tke_cls
    """
    min_tke child of limits.
    """
    min_lam_tke: min_lam_tke_cls = min_lam_tke_cls
    """
    min_lam_tke child of limits.
    """
    min_des_tke: min_des_tke_cls = min_des_tke_cls
    """
    min_des_tke child of limits.
    """
    min_epsilon: min_epsilon_cls = min_epsilon_cls
    """
    min_epsilon child of limits.
    """
    min_des_epsilon: min_des_epsilon_cls = min_des_epsilon_cls
    """
    min_des_epsilon child of limits.
    """
    min_v2f_tke: min_v2f_tke_cls = min_v2f_tke_cls
    """
    min_v2f_tke child of limits.
    """
    min_v2f_epsilon: min_v2f_epsilon_cls = min_v2f_epsilon_cls
    """
    min_v2f_epsilon child of limits.
    """
    min_vel_var_scale: min_vel_var_scale_cls = min_vel_var_scale_cls
    """
    min_vel_var_scale child of limits.
    """
    min_elliptic_relax_func: min_elliptic_relax_func_cls = min_elliptic_relax_func_cls
    """
    min_elliptic_relax_func child of limits.
    """
    min_omega: min_omega_cls = min_omega_cls
    """
    min_omega child of limits.
    """
    min_des_omega: min_des_omega_cls = min_des_omega_cls
    """
    min_des_omega child of limits.
    """
    max_turb_visc_ratio: max_turb_visc_ratio_cls = max_turb_visc_ratio_cls
    """
    max_turb_visc_ratio child of limits.
    """
    positivity_rate: positivity_rate_cls = positivity_rate_cls
    """
    positivity_rate child of limits.
    """
    min_vol_frac_for_matrix_sol: min_vol_frac_for_matrix_sol_cls = min_vol_frac_for_matrix_sol_cls
    """
    min_vol_frac_for_matrix_sol child of limits.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .calculation_method import calculation_method as calculation_method_cls
class htc(Group):
    """
    Enter the heat transfer coeficient menu.
    """

    fluent_name = "htc"

    child_names = \
        ['calculation_method']

    calculation_method: calculation_method_cls = calculation_method_cls
    """
    calculation_method child of htc.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .surfaces_1 import surfaces as surfaces_cls
from .cellzones_1 import cellzones as cellzones_cls
from .cell_func_domain import cell_func_domain as cell_func_domain_cls
class fieldview_unstruct_data(Command):
    """
    Write a Fieldview unstructured results only file.
    
    Parameters
    ----------
        name : str
            'name' child.
        surfaces : typing.List[str]
            List of surfaces to export.
        cellzones : typing.List[str]
            List of cell zones to export.
        cell_func_domain : typing.List[str]
            'cell_func_domain' child.
    
    """

    fluent_name = "fieldview-unstruct-data"

    argument_names = \
        ['name', 'surfaces', 'cellzones', 'cell_func_domain']

    name: name_cls = name_cls
    """
    name argument of fieldview_unstruct_data.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces argument of fieldview_unstruct_data.
    """
    cellzones: cellzones_cls = cellzones_cls
    """
    cellzones argument of fieldview_unstruct_data.
    """
    cell_func_domain: cell_func_domain_cls = cell_func_domain_cls
    """
    cell_func_domain argument of fieldview_unstruct_data.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .phase_16 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .p import p as p_cls
from .m import m as m_cls
from .t import t as t_cls
from .non_equil_boundary import non_equil_boundary as non_equil_boundary_cls
from .tve import tve as tve_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .ni_1 import ni as ni_cls
from .nj_1 import nj as nj_cls
from .nk_1 import nk as nk_cls
from .flow_direction_component import flow_direction_component as flow_direction_component_cls
from .axis_direction_component_1 import axis_direction_component as axis_direction_component_cls
from .axis_origin_component_1 import axis_origin_component as axis_origin_component_cls
from .ke_spec import ke_spec as ke_spec_cls
from .nut import nut as nut_cls
from .kl import kl as kl_cls
from .intermit import intermit as intermit_cls
from .k import k as k_cls
from .e import e as e_cls
from .o import o as o_cls
from .v2 import v2 as v2_cls
from .turb_intensity import turb_intensity as turb_intensity_cls
from .turb_length_scale import turb_length_scale as turb_length_scale_cls
from .turb_hydraulic_diam import turb_hydraulic_diam as turb_hydraulic_diam_cls
from .turb_viscosity_ratio import turb_viscosity_ratio as turb_viscosity_ratio_cls
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile as turb_viscosity_ratio_profile_cls
from .rst_spec import rst_spec as rst_spec_cls
from .uu import uu as uu_cls
from .vv import vv as vv_cls
from .ww import ww as ww_cls
from .uv import uv as uv_cls
from .vw import vw as vw_cls
from .uw import uw as uw_cls
from .ksgs_spec import ksgs_spec as ksgs_spec_cls
from .ksgs import ksgs as ksgs_cls
from .sgs_turb_intensity import sgs_turb_intensity as sgs_turb_intensity_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .radial_direction_component import radial_direction_component as radial_direction_component_cls
from .coll_dtheta import coll_dtheta as coll_dtheta_cls
from .coll_dphi import coll_dphi as coll_dphi_cls
from .band_q_irrad import band_q_irrad as band_q_irrad_cls
from .band_q_irrad_diffuse import band_q_irrad_diffuse as band_q_irrad_diffuse_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .solar_direction import solar_direction as solar_direction_cls
from .solar_irradiation import solar_irradiation as solar_irradiation_cls
from .t_b_b_spec import t_b_b_spec as t_b_b_spec_cls
from .t_b_b import t_b_b as t_b_b_cls
from .in_emiss import in_emiss as in_emiss_cls
from .fmean import fmean as fmean_cls
from .fvar import fvar as fvar_cls
from .fmean2 import fmean2 as fmean2_cls
from .fvar2 import fvar2 as fvar2_cls
from .species_in_mole_fractions import species_in_mole_fractions as species_in_mole_fractions_cls
from .mf import mf as mf_cls
from .elec_potential_type import elec_potential_type as elec_potential_type_cls
from .potential_value import potential_value as potential_value_cls
from .dual_potential_type import dual_potential_type as dual_potential_type_cls
from .dual_potential_value import dual_potential_value as dual_potential_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .prob_mode_1 import prob_mode_1 as prob_mode_1_cls
from .prob_mode_2 import prob_mode_2 as prob_mode_2_cls
from .prob_mode_3 import prob_mode_3 as prob_mode_3_cls
from .pollut_no import pollut_no as pollut_no_cls
from .pollut_hcn import pollut_hcn as pollut_hcn_cls
from .pollut_nh3 import pollut_nh3 as pollut_nh3_cls
from .pollut_n2o import pollut_n2o as pollut_n2o_cls
from .pollut_urea import pollut_urea as pollut_urea_cls
from .pollut_hnco import pollut_hnco as pollut_hnco_cls
from .pollut_nco import pollut_nco as pollut_nco_cls
from .pollut_so2 import pollut_so2 as pollut_so2_cls
from .pollut_h2s import pollut_h2s as pollut_h2s_cls
from .pollut_so3 import pollut_so3 as pollut_so3_cls
from .pollut_sh import pollut_sh as pollut_sh_cls
from .pollut_so import pollut_so as pollut_so_cls
from .pollut_soot import pollut_soot as pollut_soot_cls
from .pollut_nuclei import pollut_nuclei as pollut_nuclei_cls
from .pollut_ctar import pollut_ctar as pollut_ctar_cls
from .pollut_hg import pollut_hg as pollut_hg_cls
from .pollut_hgcl2 import pollut_hgcl2 as pollut_hgcl2_cls
from .pollut_hcl import pollut_hcl as pollut_hcl_cls
from .pollut_hgo import pollut_hgo as pollut_hgo_cls
from .pollut_cl import pollut_cl as pollut_cl_cls
from .pollut_cl2 import pollut_cl2 as pollut_cl2_cls
from .pollut_hgcl import pollut_hgcl as pollut_hgcl_cls
from .pollut_hocl import pollut_hocl as pollut_hocl_cls
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype as fensapice_flow_bc_subtype_cls
from .fensapice_drop_bccustom import fensapice_drop_bccustom as fensapice_drop_bccustom_cls
from .fensapice_drop_lwc import fensapice_drop_lwc as fensapice_drop_lwc_cls
from .fensapice_drop_dtemp import fensapice_drop_dtemp as fensapice_drop_dtemp_cls
from .fensapice_drop_ddiam import fensapice_drop_ddiam as fensapice_drop_ddiam_cls
from .fensapice_drop_dv import fensapice_drop_dv as fensapice_drop_dv_cls
from .fensapice_drop_dx import fensapice_drop_dx as fensapice_drop_dx_cls
from .fensapice_drop_dy import fensapice_drop_dy as fensapice_drop_dy_cls
from .fensapice_drop_dz import fensapice_drop_dz as fensapice_drop_dz_cls
from .fensapice_dpm_surface_injection import fensapice_dpm_surface_injection as fensapice_dpm_surface_injection_cls
from .fensapice_dpm_inj_nstream import fensapice_dpm_inj_nstream as fensapice_dpm_inj_nstream_cls
from .fensapice_drop_icc import fensapice_drop_icc as fensapice_drop_icc_cls
from .fensapice_drop_ctemp import fensapice_drop_ctemp as fensapice_drop_ctemp_cls
from .fensapice_drop_cdiam import fensapice_drop_cdiam as fensapice_drop_cdiam_cls
from .fensapice_drop_cv import fensapice_drop_cv as fensapice_drop_cv_cls
from .fensapice_drop_cx import fensapice_drop_cx as fensapice_drop_cx_cls
from .fensapice_drop_cy import fensapice_drop_cy as fensapice_drop_cy_cls
from .fensapice_drop_cz import fensapice_drop_cz as fensapice_drop_cz_cls
from .fensapice_drop_vrh import fensapice_drop_vrh as fensapice_drop_vrh_cls
from .fensapice_drop_vrh_1 import fensapice_drop_vrh_1 as fensapice_drop_vrh_1_cls
from .fensapice_drop_vc import fensapice_drop_vc as fensapice_drop_vc_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls
class pressure_far_field_child(Group):
    """
    'child_object_type' of pressure_far_field.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'p', 'm', 't',
         'non_equil_boundary', 'tve', 'coordinate_system', 'ni', 'nj', 'nk',
         'flow_direction_component', 'axis_direction_component',
         'axis_origin_component', 'ke_spec', 'nut', 'kl', 'intermit', 'k',
         'e', 'o', 'v2', 'turb_intensity', 'turb_length_scale',
         'turb_hydraulic_diam', 'turb_viscosity_ratio',
         'turb_viscosity_ratio_profile', 'rst_spec', 'uu', 'vv', 'ww', 'uv',
         'vw', 'uw', 'ksgs_spec', 'ksgs', 'sgs_turb_intensity',
         'radiation_bc', 'radial_direction_component', 'coll_dtheta',
         'coll_dphi', 'band_q_irrad', 'band_q_irrad_diffuse',
         'parallel_collimated_beam', 'solar_direction', 'solar_irradiation',
         't_b_b_spec', 't_b_b', 'in_emiss', 'fmean', 'fvar', 'fmean2',
         'fvar2', 'species_in_mole_fractions', 'mf', 'elec_potential_type',
         'potential_value', 'dual_potential_type', 'dual_potential_value',
         'x_displacement_type', 'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'prob_mode_1', 'prob_mode_2', 'prob_mode_3',
         'pollut_no', 'pollut_hcn', 'pollut_nh3', 'pollut_n2o', 'pollut_urea',
         'pollut_hnco', 'pollut_nco', 'pollut_so2', 'pollut_h2s',
         'pollut_so3', 'pollut_sh', 'pollut_so', 'pollut_soot',
         'pollut_nuclei', 'pollut_ctar', 'pollut_hg', 'pollut_hgcl2',
         'pollut_hcl', 'pollut_hgo', 'pollut_cl', 'pollut_cl2', 'pollut_hgcl',
         'pollut_hocl', 'fensapice_flow_bc_subtype',
         'fensapice_drop_bccustom', 'fensapice_drop_lwc',
         'fensapice_drop_dtemp', 'fensapice_drop_ddiam', 'fensapice_drop_dv',
         'fensapice_drop_dx', 'fensapice_drop_dy', 'fensapice_drop_dz',
         'fensapice_dpm_surface_injection', 'fensapice_dpm_inj_nstream',
         'fensapice_drop_icc', 'fensapice_drop_ctemp', 'fensapice_drop_cdiam',
         'fensapice_drop_cv', 'fensapice_drop_cx', 'fensapice_drop_cy',
         'fensapice_drop_cz', 'fensapice_drop_vrh', 'fensapice_drop_vrh_1',
         'fensapice_drop_vc', 'uds_bc', 'uds', 'dpm_bc_type',
         'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'solar_fluxes', 'solar_shining_factor', 'radiating_s2s_surface']

    phase: phase_cls = phase_cls
    """
    phase child of pressure_far_field_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of pressure_far_field_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of pressure_far_field_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of pressure_far_field_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of pressure_far_field_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of pressure_far_field_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of pressure_far_field_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of pressure_far_field_child.
    """
    p: p_cls = p_cls
    """
    p child of pressure_far_field_child.
    """
    m: m_cls = m_cls
    """
    m child of pressure_far_field_child.
    """
    t: t_cls = t_cls
    """
    t child of pressure_far_field_child.
    """
    non_equil_boundary: non_equil_boundary_cls = non_equil_boundary_cls
    """
    non_equil_boundary child of pressure_far_field_child.
    """
    tve: tve_cls = tve_cls
    """
    tve child of pressure_far_field_child.
    """
    coordinate_system: coordinate_system_cls = coordinate_system_cls
    """
    coordinate_system child of pressure_far_field_child.
    """
    ni: ni_cls = ni_cls
    """
    ni child of pressure_far_field_child.
    """
    nj: nj_cls = nj_cls
    """
    nj child of pressure_far_field_child.
    """
    nk: nk_cls = nk_cls
    """
    nk child of pressure_far_field_child.
    """
    flow_direction_component: flow_direction_component_cls = flow_direction_component_cls
    """
    flow_direction_component child of pressure_far_field_child.
    """
    axis_direction_component: axis_direction_component_cls = axis_direction_component_cls
    """
    axis_direction_component child of pressure_far_field_child.
    """
    axis_origin_component: axis_origin_component_cls = axis_origin_component_cls
    """
    axis_origin_component child of pressure_far_field_child.
    """
    ke_spec: ke_spec_cls = ke_spec_cls
    """
    ke_spec child of pressure_far_field_child.
    """
    nut: nut_cls = nut_cls
    """
    nut child of pressure_far_field_child.
    """
    kl: kl_cls = kl_cls
    """
    kl child of pressure_far_field_child.
    """
    intermit: intermit_cls = intermit_cls
    """
    intermit child of pressure_far_field_child.
    """
    k: k_cls = k_cls
    """
    k child of pressure_far_field_child.
    """
    e: e_cls = e_cls
    """
    e child of pressure_far_field_child.
    """
    o: o_cls = o_cls
    """
    o child of pressure_far_field_child.
    """
    v2: v2_cls = v2_cls
    """
    v2 child of pressure_far_field_child.
    """
    turb_intensity: turb_intensity_cls = turb_intensity_cls
    """
    turb_intensity child of pressure_far_field_child.
    """
    turb_length_scale: turb_length_scale_cls = turb_length_scale_cls
    """
    turb_length_scale child of pressure_far_field_child.
    """
    turb_hydraulic_diam: turb_hydraulic_diam_cls = turb_hydraulic_diam_cls
    """
    turb_hydraulic_diam child of pressure_far_field_child.
    """
    turb_viscosity_ratio: turb_viscosity_ratio_cls = turb_viscosity_ratio_cls
    """
    turb_viscosity_ratio child of pressure_far_field_child.
    """
    turb_viscosity_ratio_profile: turb_viscosity_ratio_profile_cls = turb_viscosity_ratio_profile_cls
    """
    turb_viscosity_ratio_profile child of pressure_far_field_child.
    """
    rst_spec: rst_spec_cls = rst_spec_cls
    """
    rst_spec child of pressure_far_field_child.
    """
    uu: uu_cls = uu_cls
    """
    uu child of pressure_far_field_child.
    """
    vv: vv_cls = vv_cls
    """
    vv child of pressure_far_field_child.
    """
    ww: ww_cls = ww_cls
    """
    ww child of pressure_far_field_child.
    """
    uv: uv_cls = uv_cls
    """
    uv child of pressure_far_field_child.
    """
    vw: vw_cls = vw_cls
    """
    vw child of pressure_far_field_child.
    """
    uw: uw_cls = uw_cls
    """
    uw child of pressure_far_field_child.
    """
    ksgs_spec: ksgs_spec_cls = ksgs_spec_cls
    """
    ksgs_spec child of pressure_far_field_child.
    """
    ksgs: ksgs_cls = ksgs_cls
    """
    ksgs child of pressure_far_field_child.
    """
    sgs_turb_intensity: sgs_turb_intensity_cls = sgs_turb_intensity_cls
    """
    sgs_turb_intensity child of pressure_far_field_child.
    """
    radiation_bc: radiation_bc_cls = radiation_bc_cls
    """
    radiation_bc child of pressure_far_field_child.
    """
    radial_direction_component: radial_direction_component_cls = radial_direction_component_cls
    """
    radial_direction_component child of pressure_far_field_child.
    """
    coll_dtheta: coll_dtheta_cls = coll_dtheta_cls
    """
    coll_dtheta child of pressure_far_field_child.
    """
    coll_dphi: coll_dphi_cls = coll_dphi_cls
    """
    coll_dphi child of pressure_far_field_child.
    """
    band_q_irrad: band_q_irrad_cls = band_q_irrad_cls
    """
    band_q_irrad child of pressure_far_field_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse_cls = band_q_irrad_diffuse_cls
    """
    band_q_irrad_diffuse child of pressure_far_field_child.
    """
    parallel_collimated_beam: parallel_collimated_beam_cls = parallel_collimated_beam_cls
    """
    parallel_collimated_beam child of pressure_far_field_child.
    """
    solar_direction: solar_direction_cls = solar_direction_cls
    """
    solar_direction child of pressure_far_field_child.
    """
    solar_irradiation: solar_irradiation_cls = solar_irradiation_cls
    """
    solar_irradiation child of pressure_far_field_child.
    """
    t_b_b_spec: t_b_b_spec_cls = t_b_b_spec_cls
    """
    t_b_b_spec child of pressure_far_field_child.
    """
    t_b_b: t_b_b_cls = t_b_b_cls
    """
    t_b_b child of pressure_far_field_child.
    """
    in_emiss: in_emiss_cls = in_emiss_cls
    """
    in_emiss child of pressure_far_field_child.
    """
    fmean: fmean_cls = fmean_cls
    """
    fmean child of pressure_far_field_child.
    """
    fvar: fvar_cls = fvar_cls
    """
    fvar child of pressure_far_field_child.
    """
    fmean2: fmean2_cls = fmean2_cls
    """
    fmean2 child of pressure_far_field_child.
    """
    fvar2: fvar2_cls = fvar2_cls
    """
    fvar2 child of pressure_far_field_child.
    """
    species_in_mole_fractions: species_in_mole_fractions_cls = species_in_mole_fractions_cls
    """
    species_in_mole_fractions child of pressure_far_field_child.
    """
    mf: mf_cls = mf_cls
    """
    mf child of pressure_far_field_child.
    """
    elec_potential_type: elec_potential_type_cls = elec_potential_type_cls
    """
    elec_potential_type child of pressure_far_field_child.
    """
    potential_value: potential_value_cls = potential_value_cls
    """
    potential_value child of pressure_far_field_child.
    """
    dual_potential_type: dual_potential_type_cls = dual_potential_type_cls
    """
    dual_potential_type child of pressure_far_field_child.
    """
    dual_potential_value: dual_potential_value_cls = dual_potential_value_cls
    """
    dual_potential_value child of pressure_far_field_child.
    """
    x_displacement_type: x_displacement_type_cls = x_displacement_type_cls
    """
    x_displacement_type child of pressure_far_field_child.
    """
    x_displacement_value: x_displacement_value_cls = x_displacement_value_cls
    """
    x_displacement_value child of pressure_far_field_child.
    """
    y_displacement_type: y_displacement_type_cls = y_displacement_type_cls
    """
    y_displacement_type child of pressure_far_field_child.
    """
    y_displacement_value: y_displacement_value_cls = y_displacement_value_cls
    """
    y_displacement_value child of pressure_far_field_child.
    """
    z_displacement_type: z_displacement_type_cls = z_displacement_type_cls
    """
    z_displacement_type child of pressure_far_field_child.
    """
    z_displacement_value: z_displacement_value_cls = z_displacement_value_cls
    """
    z_displacement_value child of pressure_far_field_child.
    """
    prob_mode_1: prob_mode_1_cls = prob_mode_1_cls
    """
    prob_mode_1 child of pressure_far_field_child.
    """
    prob_mode_2: prob_mode_2_cls = prob_mode_2_cls
    """
    prob_mode_2 child of pressure_far_field_child.
    """
    prob_mode_3: prob_mode_3_cls = prob_mode_3_cls
    """
    prob_mode_3 child of pressure_far_field_child.
    """
    pollut_no: pollut_no_cls = pollut_no_cls
    """
    pollut_no child of pressure_far_field_child.
    """
    pollut_hcn: pollut_hcn_cls = pollut_hcn_cls
    """
    pollut_hcn child of pressure_far_field_child.
    """
    pollut_nh3: pollut_nh3_cls = pollut_nh3_cls
    """
    pollut_nh3 child of pressure_far_field_child.
    """
    pollut_n2o: pollut_n2o_cls = pollut_n2o_cls
    """
    pollut_n2o child of pressure_far_field_child.
    """
    pollut_urea: pollut_urea_cls = pollut_urea_cls
    """
    pollut_urea child of pressure_far_field_child.
    """
    pollut_hnco: pollut_hnco_cls = pollut_hnco_cls
    """
    pollut_hnco child of pressure_far_field_child.
    """
    pollut_nco: pollut_nco_cls = pollut_nco_cls
    """
    pollut_nco child of pressure_far_field_child.
    """
    pollut_so2: pollut_so2_cls = pollut_so2_cls
    """
    pollut_so2 child of pressure_far_field_child.
    """
    pollut_h2s: pollut_h2s_cls = pollut_h2s_cls
    """
    pollut_h2s child of pressure_far_field_child.
    """
    pollut_so3: pollut_so3_cls = pollut_so3_cls
    """
    pollut_so3 child of pressure_far_field_child.
    """
    pollut_sh: pollut_sh_cls = pollut_sh_cls
    """
    pollut_sh child of pressure_far_field_child.
    """
    pollut_so: pollut_so_cls = pollut_so_cls
    """
    pollut_so child of pressure_far_field_child.
    """
    pollut_soot: pollut_soot_cls = pollut_soot_cls
    """
    pollut_soot child of pressure_far_field_child.
    """
    pollut_nuclei: pollut_nuclei_cls = pollut_nuclei_cls
    """
    pollut_nuclei child of pressure_far_field_child.
    """
    pollut_ctar: pollut_ctar_cls = pollut_ctar_cls
    """
    pollut_ctar child of pressure_far_field_child.
    """
    pollut_hg: pollut_hg_cls = pollut_hg_cls
    """
    pollut_hg child of pressure_far_field_child.
    """
    pollut_hgcl2: pollut_hgcl2_cls = pollut_hgcl2_cls
    """
    pollut_hgcl2 child of pressure_far_field_child.
    """
    pollut_hcl: pollut_hcl_cls = pollut_hcl_cls
    """
    pollut_hcl child of pressure_far_field_child.
    """
    pollut_hgo: pollut_hgo_cls = pollut_hgo_cls
    """
    pollut_hgo child of pressure_far_field_child.
    """
    pollut_cl: pollut_cl_cls = pollut_cl_cls
    """
    pollut_cl child of pressure_far_field_child.
    """
    pollut_cl2: pollut_cl2_cls = pollut_cl2_cls
    """
    pollut_cl2 child of pressure_far_field_child.
    """
    pollut_hgcl: pollut_hgcl_cls = pollut_hgcl_cls
    """
    pollut_hgcl child of pressure_far_field_child.
    """
    pollut_hocl: pollut_hocl_cls = pollut_hocl_cls
    """
    pollut_hocl child of pressure_far_field_child.
    """
    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype_cls = fensapice_flow_bc_subtype_cls
    """
    fensapice_flow_bc_subtype child of pressure_far_field_child.
    """
    fensapice_drop_bccustom: fensapice_drop_bccustom_cls = fensapice_drop_bccustom_cls
    """
    fensapice_drop_bccustom child of pressure_far_field_child.
    """
    fensapice_drop_lwc: fensapice_drop_lwc_cls = fensapice_drop_lwc_cls
    """
    fensapice_drop_lwc child of pressure_far_field_child.
    """
    fensapice_drop_dtemp: fensapice_drop_dtemp_cls = fensapice_drop_dtemp_cls
    """
    fensapice_drop_dtemp child of pressure_far_field_child.
    """
    fensapice_drop_ddiam: fensapice_drop_ddiam_cls = fensapice_drop_ddiam_cls
    """
    fensapice_drop_ddiam child of pressure_far_field_child.
    """
    fensapice_drop_dv: fensapice_drop_dv_cls = fensapice_drop_dv_cls
    """
    fensapice_drop_dv child of pressure_far_field_child.
    """
    fensapice_drop_dx: fensapice_drop_dx_cls = fensapice_drop_dx_cls
    """
    fensapice_drop_dx child of pressure_far_field_child.
    """
    fensapice_drop_dy: fensapice_drop_dy_cls = fensapice_drop_dy_cls
    """
    fensapice_drop_dy child of pressure_far_field_child.
    """
    fensapice_drop_dz: fensapice_drop_dz_cls = fensapice_drop_dz_cls
    """
    fensapice_drop_dz child of pressure_far_field_child.
    """
    fensapice_dpm_surface_injection: fensapice_dpm_surface_injection_cls = fensapice_dpm_surface_injection_cls
    """
    fensapice_dpm_surface_injection child of pressure_far_field_child.
    """
    fensapice_dpm_inj_nstream: fensapice_dpm_inj_nstream_cls = fensapice_dpm_inj_nstream_cls
    """
    fensapice_dpm_inj_nstream child of pressure_far_field_child.
    """
    fensapice_drop_icc: fensapice_drop_icc_cls = fensapice_drop_icc_cls
    """
    fensapice_drop_icc child of pressure_far_field_child.
    """
    fensapice_drop_ctemp: fensapice_drop_ctemp_cls = fensapice_drop_ctemp_cls
    """
    fensapice_drop_ctemp child of pressure_far_field_child.
    """
    fensapice_drop_cdiam: fensapice_drop_cdiam_cls = fensapice_drop_cdiam_cls
    """
    fensapice_drop_cdiam child of pressure_far_field_child.
    """
    fensapice_drop_cv: fensapice_drop_cv_cls = fensapice_drop_cv_cls
    """
    fensapice_drop_cv child of pressure_far_field_child.
    """
    fensapice_drop_cx: fensapice_drop_cx_cls = fensapice_drop_cx_cls
    """
    fensapice_drop_cx child of pressure_far_field_child.
    """
    fensapice_drop_cy: fensapice_drop_cy_cls = fensapice_drop_cy_cls
    """
    fensapice_drop_cy child of pressure_far_field_child.
    """
    fensapice_drop_cz: fensapice_drop_cz_cls = fensapice_drop_cz_cls
    """
    fensapice_drop_cz child of pressure_far_field_child.
    """
    fensapice_drop_vrh: fensapice_drop_vrh_cls = fensapice_drop_vrh_cls
    """
    fensapice_drop_vrh child of pressure_far_field_child.
    """
    fensapice_drop_vrh_1: fensapice_drop_vrh_1_cls = fensapice_drop_vrh_1_cls
    """
    fensapice_drop_vrh_1 child of pressure_far_field_child.
    """
    fensapice_drop_vc: fensapice_drop_vc_cls = fensapice_drop_vc_cls
    """
    fensapice_drop_vc child of pressure_far_field_child.
    """
    uds_bc: uds_bc_cls = uds_bc_cls
    """
    uds_bc child of pressure_far_field_child.
    """
    uds: uds_cls = uds_cls
    """
    uds child of pressure_far_field_child.
    """
    dpm_bc_type: dpm_bc_type_cls = dpm_bc_type_cls
    """
    dpm_bc_type child of pressure_far_field_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = dpm_bc_collision_partner_cls
    """
    dpm_bc_collision_partner child of pressure_far_field_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of pressure_far_field_child.
    """
    dpm_bc_udf: dpm_bc_udf_cls = dpm_bc_udf_cls
    """
    dpm_bc_udf child of pressure_far_field_child.
    """
    solar_fluxes: solar_fluxes_cls = solar_fluxes_cls
    """
    solar_fluxes child of pressure_far_field_child.
    """
    solar_shining_factor: solar_shining_factor_cls = solar_shining_factor_cls
    """
    solar_shining_factor child of pressure_far_field_child.
    """
    radiating_s2s_surface: radiating_s2s_surface_cls = radiating_s2s_surface_cls
    """
    radiating_s2s_surface child of pressure_far_field_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .delete import delete as delete_cls
from .display import display as display_cls
from .read_2 import read as read_cls
class surface_mesh(Group):
    """
    Enter the surface mesh menu.
    """

    fluent_name = "surface-mesh"

    command_names = \
        ['delete', 'display', 'read']

    delete: delete_cls = delete_cls
    """
    delete command of surface_mesh.
    """
    display: display_cls = display_cls
    """
    display command of surface_mesh.
    """
    read: read_cls = read_cls
    """
    read command of surface_mesh.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .register_based import register_based as register_based_cls
class poor_mesh_numerics(Group):
    """
    'poor_mesh_numerics' child.
    """

    fluent_name = "poor-mesh-numerics"

    child_names = \
        ['register_based']

    register_based: register_based_cls = register_based_cls
    """
    register_based child of poor_mesh_numerics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .sample_var import sample_var as sample_var_cls
from .reset_range import reset_range as reset_range_cls
class reset_min_and_max(Command):
    """
    Reset the min and max values of the range to be considered for a specific variable in the data reduction.
    
    Parameters
    ----------
        sample_var : str
            'sample_var' child.
        reset_range : bool
            'reset_range' child.
    
    """

    fluent_name = "reset-min-and-max"

    argument_names = \
        ['sample_var', 'reset_range']

    sample_var: sample_var_cls = sample_var_cls
    """
    sample_var argument of reset_min_and_max.
    """
    reset_range: reset_range_cls = reset_range_cls
    """
    reset_range argument of reset_min_and_max.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class show_periodic_shadow_zones(Boolean):
    """
    Option to show periodic shadow zones in user interface.
    """

    fluent_name = "show-periodic-shadow-zones?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_9 import option as option_cls
from .single_rate import single_rate as single_rate_cls
from .secondary_rate import secondary_rate as secondary_rate_cls
from .value import value as value_cls
class thermolysis_model(Group):
    """
    'thermolysis_model' child.
    """

    fluent_name = "thermolysis-model"

    child_names = \
        ['option', 'single_rate', 'secondary_rate', 'value']

    option: option_cls = option_cls
    """
    option child of thermolysis_model.
    """
    single_rate: single_rate_cls = single_rate_cls
    """
    single_rate child of thermolysis_model.
    """
    secondary_rate: secondary_rate_cls = secondary_rate_cls
    """
    secondary_rate child of thermolysis_model.
    """
    value: value_cls = value_cls
    """
    value child of thermolysis_model.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class injection_child:
    fluent_name = ...
    child_names = ...
    name = ...
    report_type = ...
    injection_list = ...
    boundaries = ...
    physics = ...
    per_injection = ...
    average_over = ...
    retain_instantaneous_values = ...
    mass_criterion = ...
    user_specified_origin_and_axis = ...
    origin = ...
    axis = ...
    show_unsteady_rate = ...
    inj_mass_rate_prev_time = ...
    inj_mass_rate_prev_mass = ...
    inj_mass_rate_last_flow = ...
    inj_mass_rate_last_tstp = ...
    command_names = ...

    def create_output_parameter(self, ):
        """
        'create_output_parameter' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class plot_write_sample:
    fluent_name = ...
    command_names = ...

    def plot_sample(self, sample: str, variable_to_sample: str, weighting_variable: str, correlation_variable: str, file_name: str):
        """
        'plot_sample' command.
        
        Parameters
        ----------
            sample : str
                'sample' child.
            variable_to_sample : str
                'variable_to_sample' child.
            weighting_variable : str
                'weighting_variable' child.
            correlation_variable : str
                'correlation_variable' child.
            file_name : str
                'file_name' child.
        
        """

    def write_sample(self, sample: str, variable_to_sample: str, weighting_variable: str, correlation_variable: str, file_name: str):
        """
        'write_sample' command.
        
        Parameters
        ----------
            sample : str
                'sample' child.
            variable_to_sample : str
                'variable_to_sample' child.
            weighting_variable : str
                'weighting_variable' child.
            correlation_variable : str
                'correlation_variable' child.
            file_name : str
                'file_name' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .options_8 import options as options_cls
from .edge_type import edge_type as edge_type_cls
from .shrink_factor import shrink_factor as shrink_factor_cls
from .surfaces_list import surfaces_list as surfaces_list_cls
from .coloring import coloring as coloring_cls
from .display_state_name import display_state_name as display_state_name_cls
from .physics_1 import physics as physics_cls
from .geometry_4 import geometry as geometry_cls
from .surfaces import surfaces as surfaces_cls
from .display_3 import display as display_cls
class mesh_child(Group):
    """
    'child_object_type' of mesh.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'options', 'edge_type', 'shrink_factor', 'surfaces_list',
         'coloring', 'display_state_name', 'physics', 'geometry', 'surfaces']

    name: name_cls = name_cls
    """
    name child of mesh_child.
    """
    options: options_cls = options_cls
    """
    options child of mesh_child.
    """
    edge_type: edge_type_cls = edge_type_cls
    """
    edge_type child of mesh_child.
    """
    shrink_factor: shrink_factor_cls = shrink_factor_cls
    """
    shrink_factor child of mesh_child.
    """
    surfaces_list: surfaces_list_cls = surfaces_list_cls
    """
    surfaces_list child of mesh_child.
    """
    coloring: coloring_cls = coloring_cls
    """
    coloring child of mesh_child.
    """
    display_state_name: display_state_name_cls = display_state_name_cls
    """
    display_state_name child of mesh_child.
    """
    physics: physics_cls = physics_cls
    """
    physics child of mesh_child.
    """
    geometry: geometry_cls = geometry_cls
    """
    geometry child of mesh_child.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces child of mesh_child.
    """
    command_names = \
        ['display']

    display: display_cls = display_cls
    """
    display command of mesh_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class partition_surface_child:
    fluent_name = ...
    child_names = ...
    name = ...
    partition_1 = ...
    partition_2 = ...
    interior_cell_faces = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .frame_of_reference import frame_of_reference as frame_of_reference_cls
from .gauge_pressure import gauge_pressure as gauge_pressure_cls
from .p_profile_multiplier import p_profile_multiplier as p_profile_multiplier_cls
from .direction_spec import direction_spec as direction_spec_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .flow_direction import flow_direction as flow_direction_cls
from .p_backflow_spec_gen import p_backflow_spec_gen as p_backflow_spec_gen_cls
from .p_backflow_spec import p_backflow_spec as p_backflow_spec_cls
from .axis_direction_2 import axis_direction as axis_direction_cls
from .axis_origin_2 import axis_origin as axis_origin_cls
from .prevent_reverse_flow import prevent_reverse_flow as prevent_reverse_flow_cls
from .radial import radial as radial_cls
from .avg_press_spec import avg_press_spec as avg_press_spec_cls
from .press_averaging_method import press_averaging_method as press_averaging_method_cls
from .targeted_mf_boundary import targeted_mf_boundary as targeted_mf_boundary_cls
from .targeted_mf import targeted_mf as targeted_mf_cls
from .targeted_mf_pmax import targeted_mf_pmax as targeted_mf_pmax_cls
from .targeted_mf_pmin import targeted_mf_pmin as targeted_mf_pmin_cls
from .gen_nrbc_spec import gen_nrbc_spec as gen_nrbc_spec_cls
from .ac_options import ac_options as ac_options_cls
from .impedance_0 import impedance_0 as impedance_0_cls
from .impedance_1 import impedance_1 as impedance_1_cls
from .impedance_2 import impedance_2 as impedance_2_cls
from .ac_wave import ac_wave as ac_wave_cls
from .loss_coefficient import loss_coefficient as loss_coefficient_cls
from .strength import strength as strength_cls
class momentum(Group):
    """
    Help not available.
    """

    fluent_name = "momentum"

    child_names = \
        ['frame_of_reference', 'gauge_pressure', 'p_profile_multiplier',
         'direction_spec', 'coordinate_system', 'flow_direction',
         'p_backflow_spec_gen', 'p_backflow_spec', 'axis_direction',
         'axis_origin', 'prevent_reverse_flow', 'radial', 'avg_press_spec',
         'press_averaging_method', 'targeted_mf_boundary', 'targeted_mf',
         'targeted_mf_pmax', 'targeted_mf_pmin', 'gen_nrbc_spec',
         'ac_options', 'impedance_0', 'impedance_1', 'impedance_2', 'ac_wave',
         'loss_coefficient', 'strength']

    frame_of_reference: frame_of_reference_cls = frame_of_reference_cls
    """
    frame_of_reference child of momentum.
    """
    gauge_pressure: gauge_pressure_cls = gauge_pressure_cls
    """
    gauge_pressure child of momentum.
    """
    p_profile_multiplier: p_profile_multiplier_cls = p_profile_multiplier_cls
    """
    p_profile_multiplier child of momentum.
    """
    direction_spec: direction_spec_cls = direction_spec_cls
    """
    direction_spec child of momentum.
    """
    coordinate_system: coordinate_system_cls = coordinate_system_cls
    """
    coordinate_system child of momentum.
    """
    flow_direction: flow_direction_cls = flow_direction_cls
    """
    flow_direction child of momentum.
    """
    p_backflow_spec_gen: p_backflow_spec_gen_cls = p_backflow_spec_gen_cls
    """
    p_backflow_spec_gen child of momentum.
    """
    p_backflow_spec: p_backflow_spec_cls = p_backflow_spec_cls
    """
    p_backflow_spec child of momentum.
    """
    axis_direction: axis_direction_cls = axis_direction_cls
    """
    axis_direction child of momentum.
    """
    axis_origin: axis_origin_cls = axis_origin_cls
    """
    axis_origin child of momentum.
    """
    prevent_reverse_flow: prevent_reverse_flow_cls = prevent_reverse_flow_cls
    """
    prevent_reverse_flow child of momentum.
    """
    radial: radial_cls = radial_cls
    """
    radial child of momentum.
    """
    avg_press_spec: avg_press_spec_cls = avg_press_spec_cls
    """
    avg_press_spec child of momentum.
    """
    press_averaging_method: press_averaging_method_cls = press_averaging_method_cls
    """
    press_averaging_method child of momentum.
    """
    targeted_mf_boundary: targeted_mf_boundary_cls = targeted_mf_boundary_cls
    """
    targeted_mf_boundary child of momentum.
    """
    targeted_mf: targeted_mf_cls = targeted_mf_cls
    """
    targeted_mf child of momentum.
    """
    targeted_mf_pmax: targeted_mf_pmax_cls = targeted_mf_pmax_cls
    """
    targeted_mf_pmax child of momentum.
    """
    targeted_mf_pmin: targeted_mf_pmin_cls = targeted_mf_pmin_cls
    """
    targeted_mf_pmin child of momentum.
    """
    gen_nrbc_spec: gen_nrbc_spec_cls = gen_nrbc_spec_cls
    """
    gen_nrbc_spec child of momentum.
    """
    ac_options: ac_options_cls = ac_options_cls
    """
    ac_options child of momentum.
    """
    impedance_0: impedance_0_cls = impedance_0_cls
    """
    impedance_0 child of momentum.
    """
    impedance_1: impedance_1_cls = impedance_1_cls
    """
    impedance_1 child of momentum.
    """
    impedance_2: impedance_2_cls = impedance_2_cls
    """
    impedance_2 child of momentum.
    """
    ac_wave: ac_wave_cls = ac_wave_cls
    """
    ac_wave child of momentum.
    """
    loss_coefficient: loss_coefficient_cls = loss_coefficient_cls
    """
    loss_coefficient child of momentum.
    """
    strength: strength_cls = strength_cls
    """
    strength child of momentum.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .axis import axis as axis_cls
from .degassing import degassing as degassing_cls
from .exhaust_fan import exhaust_fan as exhaust_fan_cls
from .fan import fan as fan_cls
from .geometry import geometry as geometry_cls
from .inlet_vent import inlet_vent as inlet_vent_cls
from .intake_fan import intake_fan as intake_fan_cls
from .interface import interface as interface_cls
from .interior import interior as interior_cls
from .mass_flow_inlet import mass_flow_inlet as mass_flow_inlet_cls
from .mass_flow_outlet import mass_flow_outlet as mass_flow_outlet_cls
from .network import network as network_cls
from .network_end import network_end as network_end_cls
from .outflow import outflow as outflow_cls
from .outlet_vent import outlet_vent as outlet_vent_cls
from .overset import overset as overset_cls
from .periodic import periodic as periodic_cls
from .porous_jump import porous_jump as porous_jump_cls
from .pressure_far_field import pressure_far_field as pressure_far_field_cls
from .pressure_inlet import pressure_inlet as pressure_inlet_cls
from .pressure_outlet import pressure_outlet as pressure_outlet_cls
from .radiator import radiator as radiator_cls
from .rans_les_interface import rans_les_interface as rans_les_interface_cls
from .recirculation_inlet import recirculation_inlet as recirculation_inlet_cls
from .recirculation_outlet import recirculation_outlet as recirculation_outlet_cls
from .shadow import shadow as shadow_cls
from .symmetry import symmetry as symmetry_cls
from .velocity_inlet import velocity_inlet as velocity_inlet_cls
from .wall import wall as wall_cls
class boundary_conditions(Group):
    """
    'boundary_conditions' child.
    """

    fluent_name = "boundary-conditions"

    child_names = \
        ['axis', 'degassing', 'exhaust_fan', 'fan', 'geometry', 'inlet_vent',
         'intake_fan', 'interface', 'interior', 'mass_flow_inlet',
         'mass_flow_outlet', 'network', 'network_end', 'outflow',
         'outlet_vent', 'overset', 'periodic', 'porous_jump',
         'pressure_far_field', 'pressure_inlet', 'pressure_outlet',
         'radiator', 'rans_les_interface', 'recirculation_inlet',
         'recirculation_outlet', 'shadow', 'symmetry', 'velocity_inlet',
         'wall']

    axis: axis_cls = axis_cls
    """
    axis child of boundary_conditions.
    """
    degassing: degassing_cls = degassing_cls
    """
    degassing child of boundary_conditions.
    """
    exhaust_fan: exhaust_fan_cls = exhaust_fan_cls
    """
    exhaust_fan child of boundary_conditions.
    """
    fan: fan_cls = fan_cls
    """
    fan child of boundary_conditions.
    """
    geometry: geometry_cls = geometry_cls
    """
    geometry child of boundary_conditions.
    """
    inlet_vent: inlet_vent_cls = inlet_vent_cls
    """
    inlet_vent child of boundary_conditions.
    """
    intake_fan: intake_fan_cls = intake_fan_cls
    """
    intake_fan child of boundary_conditions.
    """
    interface: interface_cls = interface_cls
    """
    interface child of boundary_conditions.
    """
    interior: interior_cls = interior_cls
    """
    interior child of boundary_conditions.
    """
    mass_flow_inlet: mass_flow_inlet_cls = mass_flow_inlet_cls
    """
    mass_flow_inlet child of boundary_conditions.
    """
    mass_flow_outlet: mass_flow_outlet_cls = mass_flow_outlet_cls
    """
    mass_flow_outlet child of boundary_conditions.
    """
    network: network_cls = network_cls
    """
    network child of boundary_conditions.
    """
    network_end: network_end_cls = network_end_cls
    """
    network_end child of boundary_conditions.
    """
    outflow: outflow_cls = outflow_cls
    """
    outflow child of boundary_conditions.
    """
    outlet_vent: outlet_vent_cls = outlet_vent_cls
    """
    outlet_vent child of boundary_conditions.
    """
    overset: overset_cls = overset_cls
    """
    overset child of boundary_conditions.
    """
    periodic: periodic_cls = periodic_cls
    """
    periodic child of boundary_conditions.
    """
    porous_jump: porous_jump_cls = porous_jump_cls
    """
    porous_jump child of boundary_conditions.
    """
    pressure_far_field: pressure_far_field_cls = pressure_far_field_cls
    """
    pressure_far_field child of boundary_conditions.
    """
    pressure_inlet: pressure_inlet_cls = pressure_inlet_cls
    """
    pressure_inlet child of boundary_conditions.
    """
    pressure_outlet: pressure_outlet_cls = pressure_outlet_cls
    """
    pressure_outlet child of boundary_conditions.
    """
    radiator: radiator_cls = radiator_cls
    """
    radiator child of boundary_conditions.
    """
    rans_les_interface: rans_les_interface_cls = rans_les_interface_cls
    """
    rans_les_interface child of boundary_conditions.
    """
    recirculation_inlet: recirculation_inlet_cls = recirculation_inlet_cls
    """
    recirculation_inlet child of boundary_conditions.
    """
    recirculation_outlet: recirculation_outlet_cls = recirculation_outlet_cls
    """
    recirculation_outlet child of boundary_conditions.
    """
    shadow: shadow_cls = shadow_cls
    """
    shadow child of boundary_conditions.
    """
    symmetry: symmetry_cls = symmetry_cls
    """
    symmetry child of boundary_conditions.
    """
    velocity_inlet: velocity_inlet_cls = velocity_inlet_cls
    """
    velocity_inlet child of boundary_conditions.
    """
    wall: wall_cls = wall_cls
    """
    wall child of boundary_conditions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class sbes_les_subgrid_dynamic_fvar(Boolean):
    """
    Enable/disable the dynamic subgrid-scale mixture fraction variance model.
    """

    fluent_name = "sbes-les-subgrid-dynamic-fvar?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .number_of_coefficients import number_of_coefficients as number_of_coefficients_cls
from .coefficients import coefficients as coefficients_cls
class polynomial(Group):
    """
    'polynomial' child.
    """

    fluent_name = "polynomial"

    child_names = \
        ['number_of_coefficients', 'coefficients']

    number_of_coefficients: number_of_coefficients_cls = number_of_coefficients_cls
    """
    number_of_coefficients child of polynomial.
    """
    coefficients: coefficients_cls = coefficients_cls
    """
    coefficients child of polynomial.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .delete_1 import delete as delete_cls
from .list import list as list_cls
from .list_properties_1 import list_properties as list_properties_cls
from .make_a_copy import make_a_copy as make_a_copy_cls
from .inlet_vent_child import inlet_vent_child

class inlet_vent(NamedObject[inlet_vent_child], _NonCreatableNamedObjectMixin[inlet_vent_child]):
    """
    'inlet_vent' child.
    """

    fluent_name = "inlet-vent"

    command_names = \
        ['delete', 'list', 'list_properties', 'make_a_copy']

    delete: delete_cls = delete_cls
    """
    delete command of inlet_vent.
    """
    list: list_cls = list_cls
    """
    list command of inlet_vent.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of inlet_vent.
    """
    make_a_copy: make_a_copy_cls = make_a_copy_cls
    """
    make_a_copy command of inlet_vent.
    """
    child_object_type: inlet_vent_child = inlet_vent_child
    """
    child_object_type of inlet_vent.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .mem_zone import mem_zone as mem_zone_cls
from .species_permeation import species_permeation as species_permeation_cls
from .mem_anode_interface import mem_anode_interface as mem_anode_interface_cls
from .mem_cathode_interface import mem_cathode_interface as mem_cathode_interface_cls
from .mem_thickness import mem_thickness as mem_thickness_cls
from .mem_cond import mem_cond as mem_cond_cls
class electrolyte(Group):
    """
    'electrolyte' child.
    """

    fluent_name = "electrolyte"

    child_names = \
        ['mem_zone', 'species_permeation', 'mem_anode_interface',
         'mem_cathode_interface', 'mem_thickness', 'mem_cond']

    mem_zone: mem_zone_cls = mem_zone_cls
    """
    mem_zone child of electrolyte.
    """
    species_permeation: species_permeation_cls = species_permeation_cls
    """
    species_permeation child of electrolyte.
    """
    mem_anode_interface: mem_anode_interface_cls = mem_anode_interface_cls
    """
    mem_anode_interface child of electrolyte.
    """
    mem_cathode_interface: mem_cathode_interface_cls = mem_cathode_interface_cls
    """
    mem_cathode_interface child of electrolyte.
    """
    mem_thickness: mem_thickness_cls = mem_thickness_cls
    """
    mem_thickness child of electrolyte.
    """
    mem_cond: mem_cond_cls = mem_cond_cls
    """
    mem_cond child of electrolyte.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class modified_setting_options:
    fluent_name = ...
    command_names = ...

    def modified_setting(self, setting_type: List[str]):
        """
        Specify which settings will be checked for non-default status for generating the Modified Settings Summary table.
        
        Parameters
        ----------
            setting_type : typing.List[str]
                'setting_type' child.
        
        """

    def write_user_setting(self, file_name: str, overwrite: bool):
        """
        Write the contents of the Modified Settings Summary table to a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
            overwrite : bool
                'overwrite' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .n_theta_divisions import n_theta_divisions as n_theta_divisions_cls
from .n_phi_divisions import n_phi_divisions as n_phi_divisions_cls
from .n_theta_pixels import n_theta_pixels as n_theta_pixels_cls
from .n_phi_pixels import n_phi_pixels as n_phi_pixels_cls
from .do_acceleration import do_acceleration as do_acceleration_cls
from .do_energy_coupling import do_energy_coupling as do_energy_coupling_cls
from .method_partially_specular_wall import method_partially_specular_wall as method_partially_specular_wall_cls
from .fast_second_order_discrete_ordinate import fast_second_order_discrete_ordinate as fast_second_order_discrete_ordinate_cls
from .blending_factor import blending_factor as blending_factor_cls
class discrete_ordinates(Group):
    """
    Enable/disable the discrete ordinates radiation model.
    """

    fluent_name = "discrete-ordinates"

    child_names = \
        ['n_theta_divisions', 'n_phi_divisions', 'n_theta_pixels',
         'n_phi_pixels', 'do_acceleration', 'do_energy_coupling',
         'method_partially_specular_wall',
         'fast_second_order_discrete_ordinate', 'blending_factor']

    n_theta_divisions: n_theta_divisions_cls = n_theta_divisions_cls
    """
    n_theta_divisions child of discrete_ordinates.
    """
    n_phi_divisions: n_phi_divisions_cls = n_phi_divisions_cls
    """
    n_phi_divisions child of discrete_ordinates.
    """
    n_theta_pixels: n_theta_pixels_cls = n_theta_pixels_cls
    """
    n_theta_pixels child of discrete_ordinates.
    """
    n_phi_pixels: n_phi_pixels_cls = n_phi_pixels_cls
    """
    n_phi_pixels child of discrete_ordinates.
    """
    do_acceleration: do_acceleration_cls = do_acceleration_cls
    """
    do_acceleration child of discrete_ordinates.
    """
    do_energy_coupling: do_energy_coupling_cls = do_energy_coupling_cls
    """
    do_energy_coupling child of discrete_ordinates.
    """
    method_partially_specular_wall: method_partially_specular_wall_cls = method_partially_specular_wall_cls
    """
    method_partially_specular_wall child of discrete_ordinates.
    """
    fast_second_order_discrete_ordinate: fast_second_order_discrete_ordinate_cls = fast_second_order_discrete_ordinate_cls
    """
    fast_second_order_discrete_ordinate child of discrete_ordinates.
    """
    blending_factor: blending_factor_cls = blending_factor_cls
    """
    blending_factor child of discrete_ordinates.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class rhie_chow_flux_specify(Boolean):
    """
    Allow specification of the the rhie-chow flux method.
    """

    fluent_name = "rhie-chow-flux-specify?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .phase_10 import phase as phase_cls
class network_child(Group):
    """
    'child_object_type' of network.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase']

    phase: phase_cls = phase_cls
    """
    phase child of network_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_12 import enabled as enabled_cls
from .h import h as h_cls
from .a import a as a_cls
from .e import e as e_cls
from .trigger_t import trigger_t as trigger_t_cls
from .e0 import e0 as e0_cls
class internal_short(Group):
    """
    'internal_short' child.
    """

    fluent_name = "internal-short"

    child_names = \
        ['enabled', 'h', 'a', 'e', 'trigger_t', 'e0']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of internal_short.
    """
    h: h_cls = h_cls
    """
    h child of internal_short.
    """
    a: a_cls = a_cls
    """
    a child of internal_short.
    """
    e: e_cls = e_cls
    """
    e child of internal_short.
    """
    trigger_t: trigger_t_cls = trigger_t_cls
    """
    trigger_t child of internal_short.
    """
    e0: e0_cls = e0_cls
    """
    e0 child of internal_short.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .pre_exponential_factor import pre_exponential_factor as pre_exponential_factor_cls
from .activation_energy import activation_energy as activation_energy_cls
class single_rate(Group):
    """
    'single_rate' child.
    """

    fluent_name = "single-rate"

    child_names = \
        ['pre_exponential_factor', 'activation_energy']

    pre_exponential_factor: pre_exponential_factor_cls = pre_exponential_factor_cls
    """
    pre_exponential_factor child of single_rate.
    """
    activation_energy: activation_energy_cls = activation_energy_cls
    """
    activation_energy child of single_rate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_name_1 import zone_name as zone_name_cls
class non_overlapping_zone_name(Command):
    """
    Get non-overlapping zone name from the associated interface zone.
    
    Parameters
    ----------
        zone_name : str
            Enter a zone name.
    
    """

    fluent_name = "non-overlapping-zone-name"

    argument_names = \
        ['zone_name']

    zone_name: zone_name_cls = zone_name_cls
    """
    zone_name argument of non_overlapping_zone_name.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .lookup_table import lookup_table as lookup_table_cls
from .composition_type import composition_type as composition_type_cls
from .species_fractions import species_fractions as species_fractions_cls
from .pressure_points import pressure_points as pressure_points_cls
from .pressure_minimum import pressure_minimum as pressure_minimum_cls
from .pressure_maximum import pressure_maximum as pressure_maximum_cls
from .temperature_points import temperature_points as temperature_points_cls
from .temperature_minimum import temperature_minimum as temperature_minimum_cls
from .temperature_maximum import temperature_maximum as temperature_maximum_cls
class real_gas_nist_mixture(Group):
    """
    'real_gas_nist_mixture' child.
    """

    fluent_name = "real-gas-nist-mixture"

    child_names = \
        ['lookup_table', 'composition_type', 'species_fractions',
         'pressure_points', 'pressure_minimum', 'pressure_maximum',
         'temperature_points', 'temperature_minimum', 'temperature_maximum']

    lookup_table: lookup_table_cls = lookup_table_cls
    """
    lookup_table child of real_gas_nist_mixture.
    """
    composition_type: composition_type_cls = composition_type_cls
    """
    composition_type child of real_gas_nist_mixture.
    """
    species_fractions: species_fractions_cls = species_fractions_cls
    """
    species_fractions child of real_gas_nist_mixture.
    """
    pressure_points: pressure_points_cls = pressure_points_cls
    """
    pressure_points child of real_gas_nist_mixture.
    """
    pressure_minimum: pressure_minimum_cls = pressure_minimum_cls
    """
    pressure_minimum child of real_gas_nist_mixture.
    """
    pressure_maximum: pressure_maximum_cls = pressure_maximum_cls
    """
    pressure_maximum child of real_gas_nist_mixture.
    """
    temperature_points: temperature_points_cls = temperature_points_cls
    """
    temperature_points child of real_gas_nist_mixture.
    """
    temperature_minimum: temperature_minimum_cls = temperature_minimum_cls
    """
    temperature_minimum child of real_gas_nist_mixture.
    """
    temperature_maximum: temperature_maximum_cls = temperature_maximum_cls
    """
    temperature_maximum child of real_gas_nist_mixture.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class high_res_tracking_enabled(Boolean):
    """
    Enable/disable high resolution tracking. Please note that high-resolution tracking is the recommended default for highest tracking robustness, accuracy and performance.
    """

    fluent_name = "high-res-tracking-enabled?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .species_diffusivity_child import species_diffusivity_child

class multicomponent_child(NamedObject[species_diffusivity_child], _NonCreatableNamedObjectMixin[species_diffusivity_child]):
    """
    'child_object_type' of multicomponent.
    """

    fluent_name = "child-object-type"

    child_object_type: species_diffusivity_child = species_diffusivity_child
    """
    child_object_type of multicomponent_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .bitrate_scale import bitrate_scale as bitrate_scale_cls
from .enable_h264 import enable_h264 as enable_h264_cls
from .bitrate import bitrate as bitrate_cls
from .compression_method import compression_method as compression_method_cls
from .keyframe import keyframe as keyframe_cls
class advance_quality(Group):
    """
    Advance Quality setting.
    """

    fluent_name = "advance-quality"

    child_names = \
        ['bitrate_scale', 'enable_h264', 'bitrate', 'compression_method',
         'keyframe']

    bitrate_scale: bitrate_scale_cls = bitrate_scale_cls
    """
    bitrate_scale child of advance_quality.
    """
    enable_h264: enable_h264_cls = enable_h264_cls
    """
    enable_h264 child of advance_quality.
    """
    bitrate: bitrate_cls = bitrate_cls
    """
    bitrate child of advance_quality.
    """
    compression_method: compression_method_cls = compression_method_cls
    """
    compression_method child of advance_quality.
    """
    keyframe: keyframe_cls = keyframe_cls
    """
    keyframe child of advance_quality.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class overset_relocation_robustness_level(Integer):
    """
    Set the robustness level for particle relocation in overset meshes.
    """

    fluent_name = "overset-relocation-robustness-level"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_properties import list_properties as list_properties_cls
from .add_zone import add_zone as add_zone_cls
from .list_zone import list_zone as list_zone_cls
from .delete_zone import delete_zone as delete_zone_cls
from .contact_resis_child import contact_resis_child

class contact_resis(ListObject[contact_resis_child]):
    """
    Contact Resistance Regions.
    """

    fluent_name = "contact-resis"

    command_names = \
        ['list_properties', 'add_zone', 'list_zone', 'delete_zone']

    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of contact_resis.
    """
    add_zone: add_zone_cls = add_zone_cls
    """
    add_zone command of contact_resis.
    """
    list_zone: list_zone_cls = list_zone_cls
    """
    list_zone command of contact_resis.
    """
    delete_zone: delete_zone_cls = delete_zone_cls
    """
    delete_zone command of contact_resis.
    """
    child_object_type: contact_resis_child = contact_resis_child
    """
    child_object_type of contact_resis.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .material import material as material_cls
from .phase_material import phase_material as phase_material_cls
class model(Group):
    """
    'model' child.
    """

    fluent_name = "model"

    child_names = \
        ['option', 'material', 'phase_material']

    option: option_cls = option_cls
    """
    option child of model.
    """
    material: material_cls = material_cls
    """
    material child of model.
    """
    phase_material: phase_material_cls = phase_material_cls
    """
    phase_material child of model.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .visible import visible as visible_cls
from .size_1 import size as size_cls
from .color_1 import color as color_cls
from .log_scale_1 import log_scale as log_scale_cls
from .format import format as format_cls
from .user_skip import user_skip as user_skip_cls
from .show_all import show_all as show_all_cls
from .position import position as position_cls
from .font_name import font_name as font_name_cls
from .font_automatic import font_automatic as font_automatic_cls
from .font_size import font_size as font_size_cls
from .length_2 import length as length_cls
from .width import width as width_cls
from .bground_transparent import bground_transparent as bground_transparent_cls
from .bground_color import bground_color as bground_color_cls
from .title_elements import title_elements as title_elements_cls
class color_map(Group):
    """
    'color_map' child.
    """

    fluent_name = "color-map"

    child_names = \
        ['visible', 'size', 'color', 'log_scale', 'format', 'user_skip',
         'show_all', 'position', 'font_name', 'font_automatic', 'font_size',
         'length', 'width', 'bground_transparent', 'bground_color',
         'title_elements']

    visible: visible_cls = visible_cls
    """
    visible child of color_map.
    """
    size: size_cls = size_cls
    """
    size child of color_map.
    """
    color: color_cls = color_cls
    """
    color child of color_map.
    """
    log_scale: log_scale_cls = log_scale_cls
    """
    log_scale child of color_map.
    """
    format: format_cls = format_cls
    """
    format child of color_map.
    """
    user_skip: user_skip_cls = user_skip_cls
    """
    user_skip child of color_map.
    """
    show_all: show_all_cls = show_all_cls
    """
    show_all child of color_map.
    """
    position: position_cls = position_cls
    """
    position child of color_map.
    """
    font_name: font_name_cls = font_name_cls
    """
    font_name child of color_map.
    """
    font_automatic: font_automatic_cls = font_automatic_cls
    """
    font_automatic child of color_map.
    """
    font_size: font_size_cls = font_size_cls
    """
    font_size child of color_map.
    """
    length: length_cls = length_cls
    """
    length child of color_map.
    """
    width: width_cls = width_cls
    """
    width child of color_map.
    """
    bground_transparent: bground_transparent_cls = bground_transparent_cls
    """
    bground_transparent child of color_map.
    """
    bground_color: bground_color_cls = bground_color_cls
    """
    bground_color child of color_map.
    """
    title_elements: title_elements_cls = title_elements_cls
    """
    title_elements child of color_map.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .reference_frame import reference_frame as reference_frame_cls
from .point import point as point_cls
from .snap_method import snap_method as snap_method_cls
from .display_3 import display as display_cls
class point_surface_child(Group):
    """
    'child_object_type' of point_surface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'reference_frame', 'point', 'snap_method']

    name: name_cls = name_cls
    """
    name child of point_surface_child.
    """
    reference_frame: reference_frame_cls = reference_frame_cls
    """
    reference_frame child of point_surface_child.
    """
    point: point_cls = point_cls
    """
    point child of point_surface_child.
    """
    snap_method: snap_method_cls = snap_method_cls
    """
    snap_method child of point_surface_child.
    """
    command_names = \
        ['display']

    display: display_cls = display_cls
    """
    display command of point_surface_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class mixing_constant(Real):
    """
    Specify the mixing constant [from 0.05 to 1.0].
    """

    fluent_name = "mixing-constant"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .constant import constant as constant_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
from .polynomial import polynomial as polynomial_cls
from .user_defined_3 import user_defined as user_defined_cls
class direct_solar_irradiation(Group):
    """
    'direct_solar_irradiation' child.
    """

    fluent_name = "direct-solar-irradiation"

    child_names = \
        ['option', 'constant', 'piecewise_linear', 'polynomial',
         'user_defined']

    option: option_cls = option_cls
    """
    option child of direct_solar_irradiation.
    """
    constant: constant_cls = constant_cls
    """
    constant child of direct_solar_irradiation.
    """
    piecewise_linear: piecewise_linear_cls = piecewise_linear_cls
    """
    piecewise_linear child of direct_solar_irradiation.
    """
    polynomial: polynomial_cls = polynomial_cls
    """
    polynomial child of direct_solar_irradiation.
    """
    user_defined: user_defined_cls = user_defined_cls
    """
    user_defined child of direct_solar_irradiation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class reaction_source_term_relaxation_factor(Real):
    """
    Reaction source term relaxation factor.
    """

    fluent_name = "reaction-source-term-relaxation-factor"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .clip_to_range import clip_to_range as clip_to_range_cls
from .minimum_1 import minimum as minimum_cls
from .maximum_1 import maximum as maximum_cls
class auto_range_off(Group):
    """
    'auto_range_off' child.
    """

    fluent_name = "auto-range-off"

    child_names = \
        ['clip_to_range', 'minimum', 'maximum']

    clip_to_range: clip_to_range_cls = clip_to_range_cls
    """
    clip_to_range child of auto_range_off.
    """
    minimum: minimum_cls = minimum_cls
    """
    minimum child of auto_range_off.
    """
    maximum: maximum_cls = maximum_cls
    """
    maximum child of auto_range_off.
    """



import pytest
from util.meshing_workflow import new_mesh_session  # noqa: F401
from util.solver_workflow import new_solver_session  # noqa: F401

from ansys.fluent.core.services.datamodel_tui import TUIMenu


@pytest.mark.skip("Failing in github")
def test_report_system_proc_stats_tui(new_solver_session, capsys) -> None:
    new_solver_session.tui.report.system.sys_stats()
    captured = capsys.readouterr()
    assert "CPU" in captured.out


def test_runtime_tui_menus(load_static_mixer_case) -> None:
    solver = load_static_mixer_case
    solver.tui.define.models.addon_module(3)
    rmf = solver.tui.define.models.resolved_MEA_fuelcells
    assert rmf is not None
    assert rmf.__class__ == TUIMenu


@pytest.mark.codegen_required
def test_python_keyword_menu_name(new_mesh_session):
    meshing = new_mesh_session
    assert "cad_options" in dir(meshing.tui.file.import_)
    assert "create_cad_assemblies" in dir(meshing.tui.file.import_.cad_options)
    meshing.tui.file.import_.cad_options.create_cad_assemblies("yes")
